# Xikolo

This is the code base for Xikolo, the foundation of the HPI MOOC platform family.

For setup and usage instructions, please see the [Xikolo pages](https://xikolo.pages.xikolo.de/web).

## Components

The web application consists of several applications / frameworks:

1. The primary Rails application
2. The application's web assets (JS, CSS, images, ...)
3. The [Ember frontend application](frontend/README.md)

### The Primary Rails Application

The primary Rails application contains all server-side application logic, rendering and processing. It consists of a classic web application and a JSON API for Ember and mobile apps.

#### Installation

Use `bundle install` to install all gems and the usual rake tasks, e.g. for creating databases. See the [local setup guide](docs/app/index.md) for details.

#### Development Server

<dl>
  <dt>Port 3000</dt>
  <dd>
    Rails HTTP application server.
  </dd>
  <dt>Port 3030<dt>
  <dd>
    Webpack development server serving assets from memory.<br />
    Additionally, it serves a HTTP proxy server forwarding other requests to the Rails application.
  <dd>
</dl>

#### Databases

All rails applications use the same database. To avoid issues, _only_ the main application contains migrations (see `db/migrate`).

Services in `services/*` must not contain their own migration.
Their `schema.rb` is symlinked to `db/schema.rb` to support calling most rake tasks, such as `db:schema:load`, which of course affects the main database.
It further allows running specs for each service locally as expected.

When adding a new migration, it _MUST_ be added to the main application only.

### Web Assets

Web assets are available from two pipelines: Rails Sprockets and a Webpack-based setup.

#### Sprockets

Sprockets assets are available at runtime or precompiled using the `rake assets:precompile` task.

The Sprockets pipeline only builds the Xikolo brand by default.
Set the `BRAND` environment variable to a single other brand to build assets for that, e.g. `BRAND=brandname`.
Building multiple brands in one step is not supported.

_Note_: This pipeline is deprecated and should not be used for new code.

#### Webpack

The new Webpack-based asset pipeline supports modern JavaScript.

Install it with `yarn install` in the project root.

A development server supporting automatic page reloading on code changes can be started with `yarn start`.
This is included when running `overmind start`.

You can manually build bundles with `yarn run build`.
Different brands can be built using the `BRAND` environment variable, default is to build the `xikolo` brand that is used for local development:

```console
BRAND=brandname yarn run build
# or
yarn run build --env BRAND=brandname
```

#### Icon Set

For the community edition, the icon set (FontAwesome Pro) is explicitly removed from the source files due to licensing conflicts.
In this case, the respective source files need to be added to `app/assets/fontawesome-pro`.

### Ember Frontend Application

The [Ember frontend application](frontend/README.md) is a JavaScript application developed standalone in the `/frontend` directory.
