DEBUG = false if typeof DEBUG is "undefined"

window.Lanalytics or= {};

class window.Lanalytics.Framework

  constructor: ->
    @eventQueue = [];
    @plugins = []

  addPlugin: (plugin) ->
    @plugins.push(plugin)

  currentUser: ->
    if gon?.user_id?
      return new Lanalytics.Model.StmtUser(gon.user_id)
    else
      return new Lanalytics.Model.AnonymousUser()

  track: (user, verb, resource, withResult = {}, inContext = {}) ->
    verb = new Lanalytics.Model.StmtVerb(verb)
    now = new Date()

    experienceStmt = new Lanalytics.Model.ExpApiStatement(user, verb, resource, now, withResult, inContext)

    @eventQueue.push(experienceStmt)

    @processEventQueue()

    console.debug("New event was tracked:", experienceStmt) if (DEBUG)

  # Resource should be an object that contains the resource type and the resource key
  trackCurrentUserDoing: (verb, resource, withResult = {}, inContext = {}) ->

    user = @currentUser()
    @track(user, verb, resource, withResult, inContext)

  processEventQueue: ->
    experienceStatement = @eventQueue.shift()

    request = new XMLHttpRequest
    request.open 'POST', '/api/v2/tracking-events', true
    request.setRequestHeader 'Content-Type', 'application/json'

    errorHandler = =>
      @eventQueue.push experienceStatement
      return

    request.onerror = errorHandler
    request.onload = ->
      if request.status < 200 or request.status >= 400
        errorHandler()
      return

    request.send experienceStatement.serializeJsonApi()


class window.Lanalytics.Plugin

  constructor: (@lanalytics) ->

  @newInstance: (lanalyticsTracker) ->
    throw "This function has to be implemented in the subclass."

# The plugin are supposed to be defined under this namesspace
window.Lanalytics.Plugins or= {};

# Init lanalytics
lanalytics = new window.Lanalytics.Framework();

ready ->
  for pluginClassName in Object.keys(Lanalytics.Plugins)
    try
      plugin = Lanalytics.Plugins[pluginClassName].newInstance(lanalytics)
      lanalytics.addPlugin(plugin)
      console.log("Lanalytics.Plugins.#{pluginClassName} found, created and added") if (DEBUG)
    catch error
      console.log("Lanalytics.Plugins.#{pluginClassName} found, but could not be instantiated") if (DEBUG)
      console.log(error.stack) if (DEBUG)
