# This plugin was created for the xikolo-web application
# in order to track JS events.
class window.Lanalytics.Plugins.JSEventsPlugin extends Lanalytics.Plugin

  # This is the interface method expected by Lanalytics
  @newInstance: (lanalytics) ->
    return new Lanalytics.Plugins.JSEventsPlugin(lanalytics)

  constructor: (lanalytics) ->
    super(lanalytics)
    this._init()

  _init: ->
    $(document).on("track-event", @trackEvent)

  _createResourceFrom: (data) ->
    return new Lanalytics.Model.StmtResource(data.resourceType, data.resource)

  _findResource: (e) ->
    # Try to find the closest resource traveling up the DOM
    resource = $(e.target.activeElement).closest('[data-lanalytics-resource]')
    if resource.length > 0
      return resource.data('lanalytics-resource')

    # Try to find any resource
    resource = $('[data-lanalytics-resource]')
    if resource.length == 0 then return null

    return resource.first().data('lanalytics-resource')

  _getResource: (e, data) ->
    if (not data.resourceType) || (not data.resource)
      resource = @_findResource(e)
      data.resourceType = resource.type
      data.resource     = resource.uuid
    stmtResource = @_createResourceFrom(data)

    return stmtResource

  _getContext: (data) ->
    inContext = {}

    # Add all context that exists on the site
    context = $('[data-lanalytics-context]')
    if context.length != 0
      context.each (i, ctx) ->
        attrs = $(ctx).data('lanalytics-context')
        inContext[key] = value for key, value of attrs

    context_cookie = $.cookie('lanalytics-context')
    if gon.in_app and context_cookie?
      context_data = JSON.parse(context_cookie)
      for key, value of context_data
        inContext[key] = value
    else
      inContext['user_agent'] = navigator?.userAgent
      inContext['screen_width'] = screen?.width
      inContext['screen_height'] = screen?.height
      if gon.build_version?
        inContext['build_version'] = gon.build_version
      client_id = getClientID()
      if client_id?
        inContext['client_id'] = client_id

    # Override all context specified in individual elements
    inContext[key] = value for key, value of data.inContext

    return inContext

  # It is important to use '=>' because then 'this' will be bound to the
  # StaticHtmlEventTracker instance (in order to access lanalytics)
  trackEvent: (e, data) =>
    inContext    = @_getContext(data)
    stmtResource = @_getResource(e, data)

    if gon?.course_id? && stmtResource.uuid != gon.course_id
      inContext['course_id'] = gon.course_id
    if gon?.section_id? && stmtResource.uuid != gon.section_id
      inContext['section_id'] = gon.section_id

    @lanalytics.trackCurrentUserDoing(
      data.verb,
      stmtResource,
      data.withResult,
      inContext
    )
