const initMdUpload = function (el) {
  const elZone = el.querySelector('.xui-mdupload-zone');

  if (!elZone || elZone.dropzone != null) {
    return;
  }

  const s3 = JSON.parse(el.dataset.s3);
  const url = el.dataset.mdupload;

  // (pre)process passed arguments:
  const s3Key = s3.key;
  const acceptedFiles = s3.content_type;
  const textArea = document.querySelector(el.dataset.textareaId);
  const { uploadId } = el.dataset;

  delete s3.key;
  delete s3.content_type;

  const dropzone = new Dropzone(elZone, {
    url,
    acceptedFiles,
    timeout: null,
    thumbnailWidth: 50,
    thumbnailHeight: 50,
  });

  dropzone.on('sending', (file, _, fd) => {
    for (const k in s3) {
      const v = s3[k];
      fd.append(k, v);
    }
    fd.append('key', s3Key + xui.upload.sanitize(file.name));
    fd.append('Content-Type', file.type);
  });

  const editorWrapper = el.closest('[data-behavior="markdown-editor-wrapper"]');
  if (editorWrapper) {
    dropzone.on('success', (file) => {
      const internalName = `upload://${uploadId}/${xui.upload.sanitize(
        file.name,
      )}`;
      const editor = editorWrapper.querySelector(
        '[data-behavior="markdown-editor-widget"]',
      );
      // Dispatches event with the uploaded file data. The markdown editor
      // (markdown-editor/index.ts) listens to it and adds it to the textarea.
      const uploadedToDropzone = new CustomEvent('markdownEditor::addLink', {
        detail: { name: file.name, url: internalName },
      });
      editor.dispatchEvent(uploadedToDropzone);
    });
  } else {
    // For old markdown editors
    dropzone.on('addedfile', (file) => {
      const internalName = `upload://${uploadId}/${xui.upload.sanitize(
        file.name,
      )}`;
      const externalName = `${url}/${s3Key}${xui.upload.sanitize(file.name)}`;
      textArea.xiUrlMapping[internalName] = externalName;
      textArea.xiUrlMappingInput.value = JSON.stringify(textArea.xiUrlMapping);
    });
  }
};

const scanMdUpload = function (node = document) {
  node.querySelectorAll('[data-mdupload]').forEach((el) => {
    initMdUpload(el);
  });
};

ready(() => scanMdUpload());

if (!window.xui) {
  window.xui = {};
}

window.xui.mdupload = {
  scan: scanMdUpload,
  init: initMdUpload,
};
