import ready from '../../util/ready';
import { ContentType, InitState } from './form-types';
import { initializeTomSelect } from '../../components/global/custom-select';
import { hideAllInputs, setDefaultTypes } from './form-helpers';
import initMarkdownEditorOnSelector from '../../util/markdown-editor';

import handleVideoType from './video';
import handlePeerAssessmentType from './peer-assessment';
import handleRichTextType from './rich-text';
import handleQuizType from './quiz';
import handleLtiExerciseType from './lti-exercise';

const appendTemplate = (id: string, parent: HTMLElement) => {
  const template = document.querySelector<HTMLTemplateElement>(id);
  const clonedTemplate = document.importNode(template!.content, true);
  parent.appendChild(clonedTemplate);
};

const toggleContentForm = (contentTypeElem: HTMLInputElement) => {
  const customForm = document.querySelector('#custom-form') as HTMLElement;
  customForm.innerHTML = '';
  appendTemplate(`#${contentTypeElem.value}-form`, customForm);

  initializeTomSelect(customForm);

  /* eslint-disable @typescript-eslint/no-explicit-any  */
  (window as any).xui.upload.scan(customForm);
  (window as any).xui.mdupload.scan(customForm);
  initMarkdownEditorOnSelector(customForm);
};

const handleFormInputs = (
  contentTypeElem: HTMLInputElement,
  exerciseTypeElem: HTMLInputElement,
  initState: InitState,
) => {
  switch (contentTypeElem.value as ContentType) {
    case 'video':
      handleVideoType();
      break;
    case 'peer_assessment':
      handlePeerAssessmentType();
      break;
    case 'rich_text':
      handleRichTextType();
      break;
    case 'quiz':
      handleQuizType(contentTypeElem, exerciseTypeElem, initState);
      break;
    case 'lti_exercise':
      handleLtiExerciseType(contentTypeElem, exerciseTypeElem);
      break;
    default:
      hideAllInputs();
  }
};

const listenToContentTypeChange = (
  contentTypeElem: HTMLInputElement,
  exerciseTypeElem: HTMLInputElement,
  initState: InitState,
) => {
  contentTypeElem.addEventListener('change', () => {
    toggleContentForm(contentTypeElem);
    handleFormInputs(contentTypeElem, exerciseTypeElem, initState);
    setDefaultTypes(contentTypeElem, exerciseTypeElem);
  });
};

const saveInitialValues = (exerciseTypeElem: HTMLInputElement): InitState => {
  // Proctoring: Save initial values. Important for manipulating the proctoring state later.
  const proctoringCheckbox = document.querySelector<HTMLInputElement>(
    '#proctoring-checkbox',
  );
  return {
    proctoring: proctoringCheckbox ? proctoringCheckbox.checked : false,
    isNotProctoringType:
      exerciseTypeElem.value !== 'main' && exerciseTypeElem.value !== 'bonus',
  };
};

ready(() => {
  const validControllerAction = document.querySelector(
    'body.items-controller.new-action, body.items-controller.edit-action',
  );
  if (!validControllerAction) return;

  const contentTypeElem = document.querySelector(
    '#xikolo_course_item_content_type',
  ) as HTMLInputElement;

  const exerciseTypeElem = document.querySelector(
    '#xikolo_course_item_exercise_type',
  ) as HTMLInputElement;

  const initState = saveInitialValues(exerciseTypeElem);
  handleFormInputs(contentTypeElem, exerciseTypeElem, initState);

  if (validControllerAction.classList.contains('new-action')) {
    listenToContentTypeChange(contentTypeElem, exerciseTypeElem, initState);
  }
});
