import setScrollMarkers from '../../util/scroll-marker';
import toggleUuids from '../toggle-uuids';
import initMarkdownEditorOnSelector from '../../util/markdown-editor';

interface Postdata {
  position: number;
  new_question_id?: string;
}

// ------------------------
// HACK: jQuery comes from Sprockets assets.
// We need jQuery in this script for the "sortable" plugin.
// ------------------------
// eslint-disable-next-line no-undef
const $ = jQuery;

const setSortableFunctionality = () => {
  $('.js-question').sortable({
    appendTo: document.body,
    handle: '.js-question-handle',
    axis: 'y',
    update: (event, ui) => {
      const question = $(ui.item);
      return $.ajax(question.attr('data-url')!, {
        data: {
          position: question.index() + 1,
        },
        type: 'POST',
      });
    },
  });
  $('.js-answer').sortable({
    appendTo: document.body,
    handle: '.js-answer-handle',
    axis: 'y',
    placeholder: 'item-placeholder',
    connectWith: '.js-answer',
    update: (event, ui) => {
      const answer = $(ui.item);
      const postdata = {
        position: answer.index() + 1,
      } as Postdata;
      if (ui.sender) {
        const newParentId = $(ui.item)
          .closest('li.section.question')
          .attr('data-id');
        postdata.new_question_id = newParentId;
      }
      return $.ajax(answer.attr('data-url')!, {
        data: postdata,
        type: 'POST',
      });
    },
  });
};

const resetQuestionForm = () => {
  const activeQuestionForm = document.querySelector<HTMLElement>(
    '#active-question-form',
  );
  const availableQuestionForms = document.querySelector<HTMLElement>(
    '#available-question-forms',
  );
  const activeQuestionElements = Array.from(
    activeQuestionForm!.children,
  ) as HTMLElement[];

  if (activeQuestionElements.length > 0) {
    [...activeQuestionElements].forEach((element) =>
      availableQuestionForms!.insertAdjacentElement('beforeend', element),
    );
  }
};

const setForm = (formType: HTMLElement) => {
  const activeQuestionForm = document.querySelector<HTMLElement>(
    '#active-question-form',
  );
  resetQuestionForm();
  activeQuestionForm!.appendChild(formType);
};

const toggleGenericFields = (display: string) => {
  const genericFields =
    document.querySelectorAll<HTMLElement>('.generic-fields');
  genericFields.forEach((element) => {
    const el = element;
    el.hidden = display === 'hide';
  });
};

const toggleQuestionForm = (selector: HTMLSelectElement) => {
  const multipleChoiceForm = document.querySelector<HTMLElement>(
    '#multiple-choice-form',
  );
  const multipleAnswerForm = document.querySelector<HTMLElement>(
    '#multiple-answer-form',
  );
  const simpleFreeTextForm = document.querySelector<HTMLElement>(
    '#simple-free-text-form',
  );
  const simpleEssayForm =
    document.querySelector<HTMLElement>('#simple-essay-form');

  toggleGenericFields('show');

  switch (selector.value) {
    case 'multiple_choice':
      setForm(multipleChoiceForm!);
      break;
    case 'multiple_answer':
      setForm(multipleAnswerForm!);
      break;
    case 'free_text':
      setForm(simpleFreeTextForm!);
      break;
    case 'essay':
      setForm(simpleEssayForm!);
      break;
    default:
      toggleGenericFields('hide');
      resetQuestionForm();
  }
};

const openQuestionsTab = (quizQuestionsTab: HTMLElement) => {
  const questions = document.querySelectorAll('ul.js-question li');
  if (questions.length > 0) {
    quizQuestionsTab.click();
  }
};

const setQuestionForm = (quizQuestions: HTMLElement) => {
  const questionTypeSelector = document.querySelector(
    '#meta_question_type',
  ) as HTMLSelectElement;

  toggleQuestionForm(questionTypeSelector);
  questionTypeSelector.addEventListener('change', () =>
    toggleQuestionForm(questionTypeSelector),
  );
  setScrollMarkers('[data-behavior="scroll-marker"]', '_scroll_position');

  /* eslint-disable @typescript-eslint/no-explicit-any  */
  (window as any).xui.upload.scan(quizQuestions);
  (window as any).xui.mdupload.scan(quizQuestions);
  initMarkdownEditorOnSelector(quizQuestions);
};

const setQuizQuestions = () => {
  const questionsWrapper = document.querySelector<HTMLTemplateElement>(
    '#quiz_questions_wrapper',
  );
  if (!questionsWrapper) return;

  const quizQuestions = document.querySelector(
    '#quiz_questions',
  ) as HTMLElement;
  const quizQuestionsTab = document.querySelector(
    'a[href="#quiz_questions"]',
  ) as HTMLElement;

  const clonedTemplate = document.importNode(questionsWrapper.content, true);
  quizQuestions.appendChild(clonedTemplate);
  openQuestionsTab(quizQuestionsTab!);
  setQuestionForm(quizQuestions);
  setSortableFunctionality();
  toggleUuids('#toggle_quiz_uuids');
};

export default setQuizQuestions;
