# frozen_string_literal: true

class Admin::VideoProvidersController < Abstract::FrontendController
  require_permission 'video.provider.manage'

  def index
    @providers = Video::Provider.all
  end

  def new
    @provider = Video::Provider.new(provider_type: params.require(:type))
  end

  def edit
    @provider = Video::Provider.find params[:id]
  end

  def create
    @provider = Video::Provider.new provider_params
    if @provider.save
      redirect_to video_providers_path
    else
      render 'new'
    end
  end

  def update
    provider = Video::Provider.find params[:id]
    provider.update! provider_params

    redirect_to video_providers_path
  end

  def destroy
    provider = Video::Provider.find params[:id]
    provider.destroy!

    redirect_to video_providers_path
  end

  private

  def provider_params
    params.require(:video_provider)
      .permit(:name, :provider_type)
      .merge(credentials: credential_params)
  end

  def credential_params
    type = params[:video_provider][:provider_type]
    handler = Video::Provider.new(provider_type: type).type

    params["video_provider_credentials_#{type}"].permit(handler.credential_attributes)
  end
end
