# frozen_string_literal: true

class Admin::VideosController < Abstract::FrontendController
  protect_from_forgery except: [:thumbnail_api_callback]

  def index
    authorize! 'video.video.manage'

    streams = Video::Stream.includes(:provider).query(params[:prefix])
    @streams = streams.paginate(page: params[:page] || 1, per_page: 50)
  end

  def thumbnail_api_callback
    if params[:video_id].present? && params[:checksum].present? && params[:Download_Link].present?
      Msgr.publish({
        video_id: params[:video_id],
                     checksum: params[:checksum],
                     counter: params[:counter],
                     thumbnail_fetch_url: params[:Download_Link],
      }, to: 'xikolo.video.thumbnail_fetch')
      render json: {
        'ok' => true,
      }
    else
      render json: {
        'error' => 'params_missing',
      }
    end
  end

  def destroy
    authorize! 'video.video.manage'

    stream = Video::Stream.find(params[:id])
    if stream.destroy
      add_flash_message :success, t(:'flash.success.video_stream_deleted')
    else
      add_flash_message :error, t(:'flash.error.video_stream_not_deleted')
    end

    redirect_to videos_path
  rescue ActiveRecord::DeleteRestrictionError
    add_flash_message :error, t(:'flash.error.video_stream_not_deleted')
    redirect_to videos_path
  end

  private

  def video_api
    @video_api ||= Xikolo.api(:video).value!
  end
end
