# frozen_string_literal: true

require 'uri'

class HelpdeskController < Abstract::FrontendController
  layout :helpdesk_layout

  before_action :set_no_cache_headers

  def send_helpdesk
    params[:mail] = current_user.email if current_user.logged_in?

    # Here you can add as much data as you want...
    data = params[:data].presence || "#{params[:userAgent]}:#{params[:cookie]}:#{params[:language]}"
    user_id = current_user.logged_in? ? current_user.id : ''

    category = params[:category]
    course_id = nil

    if Helpdesk::CategoryOptions.general?(category)
      topic = category
    elsif category.present?
      topic = 'course'
      course_id = category
    else
      topic = Helpdesk::CategoryOptions.default
    end

    Helpdesk::Ticket.create!(
      title: params[:title],
      mail: params[:mail],
      report: params[:report],
      language: I18n.locale,
      course_id:,
      url: referrer_url,
      topic:,
      user_id:,
      data:
    )
    render 'success'
  rescue ActiveRecord::RecordInvalid
    render 'error', status: :unprocessable_entity
  end

  def show
    @ticket = Helpdesk::TicketForm.new

    annotate_with_metadata(@ticket)
  end

  private

  def helpdesk_layout
    request.xhr? ? false : 'simple'
  end

  def annotate_with_metadata(ticket)
    return unless params[:data].respond_to?(:to_unsafe_h)

    ticket.data = params[:data].to_unsafe_h.map {|key, value| "#{key}=#{value}" }.join(':')
  end

  def referrer_url
    return params[:url] if params[:url]

    return if request.referer.blank?

    URI.parse(request.referer)
  rescue URI::InvalidURIError
    nil # Ignore invalid URLs
  end
end
