# frozen_string_literal: true

require 'imagecrop'

module ApplicationHelper
  def current_controller?(controller_name)
    params[:controller] == controller_name
  end

  def browser_support
    @browser_support ||= BrowserSupport.new(browser)
  end

  def hide_browser_warning?
    @in_app || cookies[:_browser_warning] == 'hide' # rubocop:disable Rails/HelperInstanceVariable
  end

  def register_webcomponent(name)
    webcomponents_registry << name
  end

  def webcomponents?(component_name = nil)
    if component_name
      webcomponents_registry.include?(component_name)
    else
      webcomponents_registry.any?
    end
  end

  def webcomponents_registry
    @webcomponents_registry ||= Set.new
  end

  def webcomponents_assets
    # The order of these elements is important:
    # 1. polyfills-ie
    # 2. custom-elements-es5-adapter
    # 3. webcomponents-bundle
    # 4. element definitions

    assets = ''

    syntax = browser_support.es6? ? 'es6' : 'es5'
    element_assets = webcomponents_registry.map do |component|
      path = asset_path("#{component}/#{syntax}/#{component}.js")

      if browser.ie?
        assets += "<script src=\"#{asset_path("#{component}/#{syntax}/polyfills-ie.js")}\"></script>"
      end

      # must not set `type="module"` for older browsers (IE 11) and the integration of Plotly in m.e.i.n.e.l
      "<script src=\"#{path}\"></script>"
    end.join

    unless browser_support.es6?
      assets += "<script src=\"#{asset_path('webcomponents/custom-elements-es5-adapter.js')}\"></script>"
    end

    assets += "<script src=\"#{asset_path('webcomponents/webcomponents-bundle.js')}\"></script>"
    assets + element_assets
  end

  def imagecrop(image_url, query_params = {})
    Imagecrop.transform(
      image_path(image_url),
      query_params
    )
  end

  def advanced_settings(column_offset: 2, &block)
    id = SecureRandom.uuid

    capture do
      concat advanced_settings_button(id, column_offset)
      concat tag.div(capture(&block), id:)
    end
  end

  def advanced_settings_button(id, column_offset)
    show_text = I18n.t :'buttons.show_advanced_settings'
    hide_text = I18n.t :'buttons.hide_advanced_settings'

    tag.div do
      tag.button(show_text, class: "btn-xs btn btn-default col-lg-offset-#{column_offset} mb15",
        data: {
          'toggle-visibility': id,
          'toggle-text-on': show_text,
          'toggle-text-off': hide_text,
        })
    end
  end
end
