# frozen_string_literal: true

module EmberHelper
  def ember_script_tags
    safe_join(ember_scripts.map {|script| javascript_include_tag(script) })
  end

  def ember_stylesheet_tags
    safe_join(ember_stylesheets.map {|sheet| stylesheet_link_tag(sheet) })
  end

  def ember_site_config
    {
      brand: Xikolo.config.brand,
      site_name: Xikolo.config.site_name,
      ui_primary_color: Xikolo.config.ui_primary_color,
    }.to_json
  end

  def ember_enabled_features
    [].tap do |features|
      features << 'recap_mode' if current_user.feature?('quiz_recap')
    end.to_json
  end

  def ember_user_features
    {}.tap do |features|
      %w[
        learner_dashboard
        learner_dashboard.progress
        learner_dashboard.course_cockpit
        learner_dashboard.performance
        learner_dashboard.learning_insights
      ].each do |feature|
        features[feature] = true if current_user.feature?(feature)
      end
    end.to_json
  end

  private

  def ember_scripts
    %w[vendor xikolo-frontend]
  end

  def ember_stylesheets
    %w[vendor xikolo-frontend]
  end
end
