# frozen_string_literal: true

module Video
  class SyncVideosJob < LongRunningApplicationJob
    queue_with_priority :eventual

    # Since this job is scheduled via cron anyway, we reduce the number of retries.
    def max_attempts
      3
    end

    def perform(provider: nil, full: false)
      return Provider.find(provider).sync(full:) if provider

      Provider.ids.each do |id|
        self.class.perform_later(provider: id, full:)
      end
    rescue ActiveRecord::RecordNotFound => e
      ::Mnemosyne.attach_error(e)
      ::Sentry.capture_exception(e)
    end
  end
end
