# frozen_string_literal: true

module LearnerEvents
  class EnrollmentEvent
    def initialize(payload)
      @payload = payload
    end

    def for_json_activity_streams
      {
        'id' => @payload[:id],
        'object' => course_fields,
        'title' => title,
      }
    end

    private

    def course_fields
      {
        'id' => @payload[:course_id],
        'url' => PublicCoursePage.platform_url(course),
        'objectType' => 'course',
        'displayName' => course.title,
      }
    end

    def title
      format(
        'User %{user} is enrolled in a course on %{site}',
        user: user['name'], site: Xikolo.config.site_name
      )
    end

    def course
      @course ||= Course::Course.find(@payload[:course_id])
    end

    def user
      @user ||= Xikolo.api(:account).value!.rel(:user).get(id: @payload[:user_id]).value!
    end
  end
end
