# frozen_string_literal: true

module PlatformLogin
  require 'addressable/uri'

  class << self
    def external?
      Xikolo.config.portal_mode&.dig('external_login', 'enabled')
    end

    def login_url
      @login_url ||= if external?
                       external_login_url
                     else
                       Rails.application.routes.url_helpers.new_session_url(
                         host: Xikolo.config.base_url.site
                       )
                     end
    end

    def external_login_url
      url = Xikolo.config.portal_mode&.dig('external_login', 'url')
      raise TypeError if url.blank?

      Addressable::URI.parse(url).to_s
    rescue Addressable::URI::InvalidURIError, TypeError
      raise Status::Redirect.new 'Invalid external login URL',
        Rails.application.routes.url_helpers.root_url(
          host: Xikolo.config.base_url.site
        )
    end
  end
end
