# frozen_string_literal: true

# This custom polymorphic name patch is based on the article at
# https://shopify.engineering/changing-polymorphic-type-rails
module Course::ItemContent
  extend ActiveSupport::Concern

  STI_CLASS_TO_TYPE = {
    'lti_exercise' => ::Lti::Exercise,
    'video' => ::Video::Video,
    'rich_text' => ::Course::Richtext,
  }.freeze

  class_methods do
    # Returns the value to be stored in the `content_type` column.
    def polymorphic_name
      STI_CLASS_TO_TYPE.invert.fetch(self)
    end
  end

  # Returns the class for the provided +name+.
  # It is used to find the class correspondent to the
  # value stored in the polymorphic type column.
  def self.polymorphic_class_for(name)
    if STI_CLASS_TO_TYPE.key?(name)
      STI_CLASS_TO_TYPE[name]
    end
  end
end
