# frozen_string_literal: true

module Course
  ##
  # A presenter for the course area layout
  #
  class LayoutPresenter
    # Initialize a new presenter
    #
    # @param course [Xikolo::Course::Course]
    # @param user [Xikolo::Common::Auth::CurrentUser::Base]
    def initialize(course, user)
      @course = course
      @user = user
    end

    delegate :id, :title, :lang, :external?, to: :@course

    include Rails.application.routes.url_helpers

    def teachers
      @course.teacher_text
    end

    # get a "full" state, used for the ribbon
    def fullstate
      @course.fullstate
    end

    def nav
      @nav ||= CourseNav.items_for(@user, @course)
    end

    def teacher_nav
      @teacher_nav ||= CourseTeacherNav.items_for(@user, @course)
    end

    def request_admin_action?
      # check if the user has teacher permissions and can access the page where
      # the action (recalculation) is triggered (course settings page)
      teacher_nav.any? && @user.allowed?('course.content.edit') && needs_recalculation?
    end

    def admin_action_path
      course_sections_path(@course)
    end

    def deadlines
      DeadlinesPresenter.new(@user, @course)
    end

    private

    def needs_recalculation?
      return false unless recalculation_enabled?

      @user.allowed?('course.course.recalculate') &&
        the_course.needs_recalculation?
    end

    def recalculation_enabled?
      Xikolo.config.persisted_learning_evaluation.present?
    end

    def the_course
      @the_course ||= ::Course::Course.find(@course.id)
    end
  end
end
