# frozen_string_literal: true

module Xikolo::Video
  class Video < Acfs::Resource
    service Xikolo::Video::Client, path: 'videos'

    include Xikolo::Video::Concerns::Video

    attribute :id, :string
    attribute :title, :string
    attribute :description, :string

    attribute :lecturer_stream_id, :string
    attribute :slides_stream_id, :string
    attribute :pip_stream_id, :string
    attribute :subtitled_stream_id, :string

    attribute :slides_url, :string
    attribute :transcript_url, :string
    attribute :reading_material_url, :string

    attribute :thumbnail, :string
    attribute :duration, :integer
    attribute :subtitles, :list

    def lecturer_stream(&)
      return unless lecturer_stream_id

      @lecturer_stream ||= Xikolo::Video::Stream.find_by id: lecturer_stream_id
      Acfs.add_callback(@lecturer_stream, &)
      @lecturer_stream
    end

    def lecturer_stream_collection
      return [] unless lecturer_stream_id
      return [] if @lecturer_stream.blank?

      [[
        "#{@lecturer_stream.title} (#{@lecturer_stream['provider']['name']})",
        lecturer_stream_id,
      ]]
    end

    def slides_stream(&)
      return unless slides_stream_id

      @slides_stream ||= Xikolo::Video::Stream.find_by id: slides_stream_id
      Acfs.add_callback(@slides_stream, &)
      @slides_stream
    end

    def slides_stream_collection
      return [] unless slides_stream_id
      return [] if @slides_stream.blank?

      [[
        "#{@slides_stream.title} (#{@slides_stream['provider']['name']})",
        slides_stream_id,
      ]]
    end

    def subtitled_stream(&)
      return unless subtitled_stream_id

      @subtitled_stream ||= Xikolo::Video::Stream.find_by id: subtitled_stream_id
      Acfs.add_callback(@subtitled_stream, &)
      @subtitled_stream
    end

    def subtitled_stream_collection
      return [] unless subtitled_stream_id
      return [] if @subtitled_stream.blank?

      [[
        "#{@subtitled_stream.title} (#{@subtitled_stream['provider']['name']})",
        subtitled_stream_id,
      ]]
    end

    def pip_stream(&)
      return unless pip_stream_id

      @pip_stream ||= Xikolo::Video::Stream.find_by id: pip_stream_id
      Acfs.add_callback(@pip_stream, &)
      @pip_stream
    end

    def pip_stream_collection
      return [] unless pip_stream_id
      return [] if @pip_stream.blank?

      [[
        "#{@pip_stream.title} (#{@pip_stream['provider']['name']})",
        pip_stream_id,
      ]]
    end
  end
end
