import { bool } from '@ember/object/computed';
import $ from 'jquery';
import { computed } from '@ember/object';
import Component from '@ember/component';
import DS from 'ember-data';

export default Component.extend({
  classNames: ['course-points-progression'],

  timebasedPointsData: computed('course', function() {
    const courseDatesParams = `start_date=${this.get(
      'course.startAt'
    ).toISOString()}&end_date=${this.get('course.endAt').toISOString()}`;
    const promise = $.getJSON(
      `/api/v2/learning_insights/progression/timebased_quiz_points.json?course_id=${this.get(
        'course.id'
      )}&${courseDatesParams}`
    );
    return DS.PromiseObject.create({ promise: promise });
  }),
  timebasedPointsDataAvailable: bool('timebasedPointsData.isFulfilled'),
  pointsProgression: computed(
    'timebasedPointsData.content',
    'achievedPoints',
    'maximumPoints',
    function() {
      const keys = Object.keys(this.get('timebasedPointsData.content'));
      const points = Object.values(this.get('timebasedPointsData.content')).map(
        (t) => t['cumulative_points']
      );
      const maxPoints = Object.values(
        this.get('timebasedPointsData.content')
      ).map((t) => t['cumulative_max_points']);
      return [
        {
          x: keys,
          y: points,
          name: this.get('achievedPoints'),
          mode: 'lines+markers',
          fill: 'tonexty',
          line: { color: '#de6212' },
        },
        {
          x: keys,
          y: maxPoints,
          name: this.get('maximumPoints'),
          mode: 'lines+markers',
          fill: 'tonexty',
          line: { color: '#b42946' },
        },
      ];
    }
  ),
  courseDatesRange: computed('course.{startAt,endAt}', function() {
    return [
      this.get('course.startAt').format('YYYY-MM-DD'),
      this.get('course.endAt').format('YYYY-MM-DD'),
    ];
  }),
  totalPoints: computed(function() {
    return this.intl.t('progress.course_points_progression.total_points');
  }),
  achievedPoints: computed(function() {
    return this.intl.t('progress.course_points_progression.achieved_points');
  }),
  maximumPoints: computed(function() {
    return this.intl.t('progress.course_points_progression.maximum_points');
  }),
});
