import { bool, mapBy, sum, gt, or } from '@ember/object/computed';
import { computed } from '@ember/object';
import $ from 'jquery';
import Component from '@ember/component';
import DS from 'ember-data';

class BaseCategory {
  constructor(timeTotal, timeCompleted) {
    this.timeTotal = timeTotal;
    this.timeCompleted = timeCompleted;
    this.isAvailable = this.isAvailable();
    this.remainingTime = this.remainingTime();
    this.isTimeRemaining = this.isTimeRemaining();
    this.percentage = this.percentage();
  }

  isAvailable() {
    return this.timeTotal > 0;
  }

  remainingTime() {
    if (!this.isAvailable) return 0;
    return Math.max(0, this.timeTotal - this.timeCompleted);
  }

  isTimeRemaining() {
    return this.remainingTime > 0;
  }

  percentage() {
    if (!this.isAvailable) return 100;
    if (this.timeCompleted === 0) return 0;
    return Math.floor((this.timeCompleted * 100.0) / this.timeTotal);
  }
}

class VideoCategory extends BaseCategory {
  constructor(timeEstimationData) {
    super(
      timeEstimationData.get('content.video.total') || 0,
      timeEstimationData.get('content.video.completed') || 0
    );
    this.forCategoryKey = 'for_videos';
    this.categoryKey = 'videos';
  }
}

class ExercisesCategory extends BaseCategory {
  constructor(timeEstimationData) {
    super(
      (timeEstimationData.get('content.quiz.total') || 0) +
        (timeEstimationData.get('content.peer_assessment.total') || 0) +
        (timeEstimationData.get('content.lti_exercise.total') || 0),
      (timeEstimationData.get('content.quiz.completed') || 0) +
        (timeEstimationData.get('content.peer_assessment.completed') || 0) +
        (timeEstimationData.get('content.lti_exercise.completed') || 0)
    );
    this.forCategoryKey = 'for_quizzes';
    this.categoryKey = 'quizzes';
  }
}

class RichtextCategory extends BaseCategory {
  constructor(timeEstimationData) {
    super(
      timeEstimationData.get('content.rich_text.total') || 0,
      timeEstimationData.get('content.rich_text.completed') || 0
    );
    this.forCategoryKey = 'for_readings';
    this.categoryKey = 'readings';
  }
}

export default Component.extend({
  classNames: ['course-time-estimation'],

  didRender() {
    $('.course-time-estimation .progress .progress-bar-success').progressbar({
      transition_delay: 250,
      display_text: 'center',
    });
  },
  categories: computed('timeEstimationData', function() {
    return [
      new VideoCategory(this.get('timeEstimationData')),
      new ExercisesCategory(this.get('timeEstimationData')),
      new RichtextCategory(this.get('timeEstimationData')),
    ];
  }),
  timeEstimationData: computed('course', function() {
    const promise = $.getJSON(
      `/api/v2/courses/${this.get('course.id')}/time_effort.json`
    );
    return DS.PromiseObject.create({ promise: promise });
  }),
  timeEstimationDataAvailable: bool('timeEstimationData.isFulfilled'),
  remainingTime: mapBy('categories', 'remainingTime'),
  sumRemainingTime: sum('remainingTime'),
  isTimeRemaining: gt('sumRemainingTime', 0),
  isEstimationComplete: computed('timeEstimationData', function() {
    return (
      this.get('isContentDataAvailable') &&
      Object.values(this.get('timeEstimationData.content')).isEvery(
        'estimation_complete',
        true
      )
    );
  }),
  contentDataAvailable: mapBy('categories', 'isAvailable'),
  isContentDataAvailable: or('contentDataAvailable'),
});
