import { computed } from '@ember/object';
import Component from '@ember/component';
import { flatMap, flow, map, uniq, sortBy } from 'lodash-es';

export default Component.extend({
  actions: {
    reset() {
      this.set('languageFilter', 'all');
      this.set('tagFilter', 'all');
    },
  },

  isFiltered: computed('languageFilter', 'tagFilter', function() {
    return (
      this.get('languageFilter') !== 'all' || this.get('tagFilter') !== 'all'
    );
  }),

  showTags: computed('tags', function() {
    return this.get('tags').length > 1;
  }),

  languages: computed('documents', function() {
    return flow(
      (documents) =>
        flatMap(documents, (document) =>
          document.get('localizations').toArray()
        ),
      (localizations) =>
        flatMap(localizations, (localization) => localization.get('language')),
      (languages) => sortBy(uniq(languages), (language) => language),
      (sorted) => map(sorted, (language) => ({ id: language, name: language }))
    )(this.get('documents').toArray());
  }),

  tags: computed('documents', function() {
    return flow(
      (documents) => flatMap(documents, (document) => document.get('tags')),
      (tags) => sortBy(uniq(tags), (tag) => tag),
      (sorted) => map(sorted, (tag) => ({ id: tag, name: tag }))
    )(this.get('documents').toArray());
  }),
});
