import { computed } from '@ember/object';
import { alias } from '@ember/object/computed';
import Component from '@ember/component';

export default Component.extend({
  classNames: ['exercise-performance-overview'],

  selftestsTaken: alias('progress.selftestExercises.exercises_taken'),
  selftestsAvailable: alias('progress.selftestExercises.exercises_available'),
  assignmentsTaken: alias('progress.mainExercises.exercises_taken'),
  assignmentsAvailable: alias('progress.mainExercises.exercises_available'),
  assignmentPointsScored: computed(
    'progress.mainExercises.points_scored',
    function() {
      return this.formatPoints(
        this.get('progress.mainExercises.points_scored')
      );
    }
  ),
  assignmentPointsPossible: computed(
    'progress.mainExercises.points_possible',
    function() {
      return this.formatPoints(
        this.get('progress.mainExercises.points_possible')
      );
    }
  ),
  assignmentPointsPercentage: computed(
    'progress.mainExercises.{points_scored,points_possible}',
    function() {
      return this.calculatePercentage(
        this.get('progress.mainExercises.points_scored'),
        this.get('progress.mainExercises.points_possible')
      );
    }
  ),
  selftestPointsScored: computed(
    'progress.selftestExercises.points_scored',
    function() {
      return this.formatPoints(
        this.get('progress.selftestExercises.points_scored')
      );
    }
  ),
  selftestPointsPossible: computed(
    'progress.selftestExercises.points_possible',
    function() {
      return this.formatPoints(
        this.get('progress.selftestExercises.points_possible')
      );
    }
  ),
  selftestPointsPercentage: computed(
    'progress.selftestExercises.{points_scored,points_possible}',
    function() {
      return this.calculatePercentage(
        this.get('progress.selftestExercises.points_scored'),
        this.get('progress.selftestExercises.points_possible')
      );
    }
  ),

  calculatePercentage(scoredPoints, possiblePoints) {
    if (!scoredPoints || !possiblePoints) return 0;
    const percentage = Math.floor((scoredPoints * 100.0) / possiblePoints);
    if (percentage > 100) return 100;
    return percentage;
  },
  formatPoints(points) {
    return points.toFixed(1);
  },
});
