import { bool } from '@ember/object/computed';
import $ from 'jquery';
import { computed } from '@ember/object';
import { inject as service } from '@ember/service';
import Component from '@ember/component';
import DS from 'ember-data';

export default Component.extend({
  config: service(),
  timebasedVisitsData: computed('course', function() {
    const courseDatesParams = `start_date=${this.get(
      'course.startAt'
    ).toISOString()}&end_date=${this.get('course.endAt').toISOString()}`;
    const promise = $.getJSON(
      `/api/v2/learning_insights/progression/timebased_visits.json?course_id=${this.get(
        'course.id'
      )}&${courseDatesParams}`
    );
    return DS.PromiseObject.create({ promise: promise });
  }),
  timebasedVisitsDataAvailable: bool('timebasedVisitsData.isFulfilled'),
  timebasedVisits: computed(
    'timebasedVisitsData.{unique_visits,total_visits}',
    'uniqueItems',
    'totalVisits',
    function() {
      const keys = Object.keys(this.get('timebasedVisitsData.unique_visits'));
      const unique_visits = Object.values(
        this.get('timebasedVisitsData.unique_visits')
      ).map((t) => t['cumulative_visits']);
      const total_visits = Object.values(
        this.get('timebasedVisitsData.total_visits')
      ).map((t) => t['cumulative_visits']);
      return [
        {
          x: keys,
          y: unique_visits,
          mode: 'lines+markers',
          fill: 'tonexty',
          name: this.get('uniqueItems'),
          line: { color: '#de6212' },
        },
        {
          x: keys,
          y: total_visits,
          mode: 'lines+markers',
          fill: 'tonexty',
          name: this.get('totalVisits'),
          line: { color: '#b42946' },
        },
      ];
    }
  ),
  courseDatesRange: computed('course.{startAt,endAt}', function() {
    return [
      this.get('course.startAt').format('YYYY-MM-DD'),
      this.get('course.endAt').format('YYYY-MM-DD'),
    ];
  }),
  numberVisits: computed(function() {
    return this.intl.t('progress.item_visits_progression.number_visits');
  }),
  uniqueItems: computed(function() {
    return this.intl.t('progress.item_visits_progression.unique_items');
  }),
  totalVisits: computed(function() {
    return this.intl.t('progress.item_visits_progression.total_visits');
  }),
});
