import { computed } from '@ember/object';
import { bool, gt, or } from '@ember/object/computed';
import { inject as service } from '@ember/service';
import Component from '@ember/component';

export default Component.extend({
  classNames: ['learner-dashboard'],

  userFeatures: service(),

  /* Feature flipper */
  isCourseProgressActivated: computed(function() {
    return this.get('userFeatures')
      .feature('learner_dashboard.progress')
      .isEnabled();
  }),
  isCourseCockpitActivated: computed(function() {
    return this.get('userFeatures')
      .feature('learner_dashboard.course_cockpit')
      .isEnabled();
  }),
  isPerformanceFeedbackActivated: computed(function() {
    return this.get('userFeatures')
      .feature('learner_dashboard.performance')
      .isEnabled();
  }),
  areLearningInsightsActivated: computed(function() {
    return this.get('userFeatures')
      .feature('learner_dashboard.learning_insights')
      .isEnabled();
  }),

  /* My learning progress */
  isCourseProgressAvailable: bool('courseProgress'),
  sectionProgresses: computed(
    'courseProgress.sectionProgresses.[]',
    function() {
      return this.get('courseProgress.sectionProgresses').rejectBy(
        'parent',
        true
      );
    }
  ),
  isAnySectionAccessible: computed('sectionProgresses.[]', function() {
    return this.get('sectionProgresses').isAny('available');
  }),
  courseVisitsPercentage: computed('courseProgress.visits', function() {
    const percentage = this.get('courseProgress.visits.visits_percentage');
    if (!percentage) return 0;
    if (percentage > 100) return 100;
    return percentage;
  }),
  coursePointsGradedPercentage: computed(
    'courseProgress.{mainExercises,bonusExercises}',
    function() {
      return this.calculatePercentage(
        this.get('courseProgress.mainExercises.points_scored') +
          this.get('courseProgress.bonusExercises.points_scored'),
        this.get('courseProgress.mainExercises.points_possible')
      );
    }
  ),
  coursePointsGradedScored: computed(
    'courseProgress.{mainExercises,bonusExercises}',
    function() {
      return this.formatPoints(
        this.get('courseProgress.mainExercises.points_scored') +
          this.get('courseProgress.bonusExercises.points_scored')
      );
    }
  ),
  coursePointsGradedPossible: computed(
    'courseProgress.{mainExercises,bonusExercises}',
    function() {
      return this.formatPoints(
        this.get('courseProgress.mainExercises.points_possible')
      );
    }
  ),
  showAssignmentsProgress: or('areMainExercisesAvailable', 'areBonusExercisesAvailable'),
  areMainExercisesAvailable: gt('courseProgress.mainExercises.points_possible', 0),
  areBonusExercisesAvailable: gt('courseProgress.bonusExercises.points_possible', 0),
  coursePointsSelftestsPercentage: computed(
    'courseProgress.selftestExercises.{points_scored,points_possible}',
    function() {
      return this.calculatePercentage(
        this.get('courseProgress.selftestExercises.points_scored'),
        this.get('courseProgress.selftestExercises.points_possible')
      );
    }
  ),
  coursePointsSelftestsScored: computed(
    'courseProgress.selftestExercises.points_scored',
    function() {
      return this.formatPoints(
        this.get('courseProgress.selftestExercises.points_scored')
      );
    }
  ),
  coursePointsSelftestsPossible: computed(
    'courseProgress.selftestExercises.points_possible',
    function() {
      return this.formatPoints(
        this.get('courseProgress.selftestExercises.points_possible')
      );
    }
  ),
  showSelftestsProgress: gt('courseProgress.selftestExercises.points_possible', 0),

  calculatePercentage(scoredPoints, possiblePoints) {
    if (!scoredPoints || !possiblePoints) return 0;
    const percentage = Math.floor((scoredPoints * 100.0) / possiblePoints);
    if (percentage > 100) return 100;
    return percentage;
  },
  formatPoints(points) {
    return points.toFixed(1);
  },
});
