import { htmlSafe } from '@ember/template';
import { computed } from '@ember/object';
import Component from '@ember/component';
import compactPagination from 'compact-pagination';

const PAGE_WINDOW = 3;

export default Component.extend({
  currentPage: computed('current', function() {
    return Number(this.get('current'));
  }),

  totalPages: computed('total', function() {
    return Number(this.get('total'));
  }),

  pages: computed('currentPage', 'totalPages', function() {
    return compactPagination({
      totalSize: this.get('totalPages'),
      currentIndex: this.get('currentPage'),
      bufferSize: PAGE_WINDOW,
    }).map((item) => {
      if (item.isSeparator) {
        return { dots: true };
      } else {
        return {
          number: item.page,
          current: item.isCurrent,
        };
      }
    });
  }),

  prevPageString: htmlSafe('&lt;'),
  nextPageString: htmlSafe('&gt;'),

  prevPage: computed('currentPage', function() {
    return this.get('currentPage') - 1;
  }),

  nextPage: computed('currentPage', function() {
    return this.get('currentPage') + 1;
  }),

  canStepBackward: computed('currentPage', function() {
    return this.get('currentPage') > 1;
  }),

  canStepForward: computed('currentPage', 'totalPages', function() {
    return this.get('currentPage') < this.get('totalPages');
  }),
});
