import Component from '@ember/component';

export default Component.extend({
  classNames: ['plotly-heatmap'],

  init() {
    this._super(...arguments);
    this.setProperties({
      chartLayout: {
        // Layout options
        // See https://plot.ly/javascript/reference/#layout
        yaxis: {
          fixedrange: true,
          tickmode: 'linear',
          tick0: 1,
          dtick: 2,
          title: this.get('yaxisTitle'),
        },
        xaxis: {
          fixedrange: true,
          title: this.get('xaxisTitle'),
        },
        margin: {
          l: 100,
          r: 10,
          b: 50,
          t: 10,
          pad: 4,
        },
      },
      chartConfig: {
        displayModeBar: false,
        // Override default options from config/environment.js & plotly.js
        // See https://github.com/plotly/plotly.js/blob/master/src/plot_api/plot_config.js
      },
      // Component will listen for these events and forward them via onPlotlyEvent
      plotlyEvents: [],
      chartData: [
        {
          x: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
          y: [
            '11 PM',
            '10 PM',
            '9 PM',
            '8 PM',
            '7 PM',
            '6 PM',
            '5 PM',
            '4 PM',
            '3 PM',
            '2 PM',
            '1 PM',
            '12 PM',
            '11 AM',
            '10 AM',
            '9 AM',
            '8 AM',
            '7 AM',
            '6 AM',
            '5 AM',
            '4 AM',
            '3 AM',
            '2 AM',
            '1 AM',
            '12 AM',
          ].reverse(),
          z: this.get('chartZ'),
          xgap: 2,
          ygap: 2,
          type: 'heatmap',
          hovertemplate: this.get('hoverTemplate') + '<extra></extra>', // the empty extra tag hides the secondary box
          colorscale: [
            [0, '#F5E8BB'],
            [1, '#930517'],
          ],
        },
      ],
    });
  },
});
