import { htmlSafe } from '@ember/template';
import { alias, equal, or } from '@ember/object/computed';
import { isPresent } from '@ember/utils';
import { computed } from '@ember/object';
import { inject as service } from '@ember/service';
import $ from 'jquery';
import Component from '@ember/component';

export default Component.extend({
  classNames: ['progress-item'],
  classNameBindings: [
    'showVisited:visited',
    'showCompleted:completed',
    'showWarning:warning',
    'showCritical:critical',
    'isOptional:optional',
  ],
  attributeBindings: ['style'],

  didInsertElement() {
    $('.progress-item > a > .with-tooltip').tooltip();
  },

  store: service(),
  courseItem: computed('progressItem', function() {
    return this.get('store').peekRecord(
      'course-item',
      this.get('progressItem.id'),
    );
  }),
  icon: computed('courseItem.icon', function() {
    switch (this.get('courseItem.icon')) {
      case 'quiz': return 'lightbulb-on';
      case 'homework': return 'money-check-pen';
      case 'bonus_quiz': return 'lightbulb-on'; // overlay missing
      case 'survey': return 'clipboard-list-check';
      case 'lti_exercise': return 'display-code';
      case 'bonus_lti_exercise': return 'display-code'; // overlay missing
      case 'exercise': return 'keyboard';
      case 'youtube': return 'video'; // overlay missing
      case 'moderator': return 'microphone-lines';
      case 'assistant': return 'head-side-headphones';
      case 'external_video': return 'video'; // overlay missing
      case 'team_exercise': return 'users';
      case 'chart': return 'chart-column';
      case 'discussion': return 'comments';
      case 'rich_text': return 'file-lines';
      case 'video': return 'video';
      default: return this.get('courseItem.icon');
    }
  }),
  title: alias('courseItem.title'),
  timeEffort: alias('courseItem.formattedTimeEffort'),
  additionalInfo: computed(
    'isOptional',
    'timeEffort',
    'optionalInfo',
    'timeEffortInfo',
    function() {
      if (!this.get('isOptional') && !this.get('timeEffort')) return '';
      return ` (${[this.get('optionalInfo'), this.get('timeEffortInfo')]
        .compact()
        .join(', ')})`;
    },
  ),
  timeEffortInfo: computed('timeEffort', function() {
    if (isPresent('timeEffort')) return this.get('timeEffort');
  }),
  optionalInfo: computed('isOptional', function() {
    if (this.get('isOptional')) return this.intl.t('progress.optional');
  }),
  itemUrl: alias('courseItem.itemUrl'),
  style: computed('percentage', function() {
    return htmlSafe(`--percentage: ${this.get('stylePercentage')};`);
  }),
  isOptional: alias('courseItem.optional'),
  isQuiz: equal('courseItem.contentType', 'quiz'),
  isLtiExercise: equal('courseItem.contentType', 'lti_exercise'),
  isQuizOrLtiExercise: or('isQuiz', 'isLtiExercise'),
  isVisited: equal('progressItem.user_state', 'visited'),
  isSubmitted: equal('progressItem.user_state', 'submitted'),
  isGraded: equal('progressItem.user_state', 'graded'),
  isItemTaken: or('isGraded', 'isSubmitted'),
  showVisited: or('isVisited', 'isGraded', 'isSubmitted'),
  showCompleted: computed(
    'isQuizOrLtiExercise',
    'isVisited',
    'isItemTaken',
    'percentage',
    function() {
      if (!this.get('isQuizOrLtiExercise')) return this.get('isVisited');
      return this.get('isItemTaken') && this.get('percentage') > 95;
    },
  ),
  showWarning: computed(
    'isQuizOrLtiExercise',
    'isItemTaken',
    'showCritical',
    'percentage',
    function() {
      if (
        !this.get('isQuizOrLtiExercise') ||
        !this.get('isItemTaken') ||
        this.get('showCritical')
      )
        return false;
      return this.get('percentage') >= 50 && this.get('percentage') <= 95;
    },
  ),
  showCritical: computed('isQuizOrLtiExercise', 'percentage', function() {
    if (!this.get('isQuizOrLtiExercise')) return false;
    return this.get('percentage') < 50;
  }),
  percentage: computed(
    'isQuizOrLtiExercise',
    'isVisited',
    'progressItem.{user_points,max_points}',
    function() {
      if (!this.get('isQuizOrLtiExercise')) return 100;
      if (this.get('isVisited')) return 0;
      if (!this.get('progressItem.max_points')) return 100;
      const percentage = Math.floor(
        (this.get('progressItem.user_points') * 100.0) /
          this.get('progressItem.max_points'),
      );
      if (!percentage) return 0;
      if (percentage > 100) return 100;
      return percentage;
    },
  ),
  stylePercentage: computed('percentage', function() {
    return `${Math.max(this.get('percentage'), 15)}%`;
  }),
});
