import { gt, or, alias } from '@ember/object/computed';
import { computed } from '@ember/object';
import $ from 'jquery';
import Component from '@ember/component';

export default Component.extend({
  classNames: ['progress-section-container'],

  didRender() {
    $('.progress-section-container .progress .progress-bar-success').progressbar({
      transition_delay: 250,
      display_text: 'center',
    });
  },

  gradedExercisesAvailable: or('assignmentsAvailable', 'bonusExercisesAvailable'),
  pointsGradedPercentage: computed(
    'sectionProgress.{mainExercises,bonusExercises}',
    function() {
      return this.calculatePercentage(
        this.get('sectionProgress.mainExercises.points_scored') +
          this.get('sectionProgress.bonusExercises.points_scored'),
        this.get('sectionProgress.mainExercises.points_possible')
      );
    }
  ),
  pointsGradedScored: computed(
    'sectionProgress.{mainExercises,bonusExercises}',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.mainExercises.points_scored') +
          this.get('sectionProgress.bonusExercises.points_scored')
      );
    }
  ),
  pointsGradedPossible: computed(
    'sectionProgress.{mainExercises,bonusExercises}',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.mainExercises.points_possible')
      );
    }
  ),
  selftestsAvailable: gt('sectionProgress.selftestExercises.exercises_available', 0),
  pointsSelftestsPercentage: computed(
    'sectionProgress.selftestExercises.{points_scored,points_possible}',
    function() {
      return this.calculatePercentage(
        this.get('sectionProgress.selftestExercises.points_scored'),
        this.get('sectionProgress.selftestExercises.points_possible')
      );
    }
  ),
  pointsSelftestsScored: computed(
    'sectionProgress.selftestExercises.points_scored',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.selftestExercises.points_scored')
      );
    }
  ),
  pointsSelftestsPossible: computed(
    'sectionProgress.selftestExercises.points_possible',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.selftestExercises.points_possible')
      );
    }
  ),
  bonusExercisesAvailable: gt('sectionProgress.bonusExercises.exercises_available', 0),
  pointsBonusPercentage: computed(
    'sectionProgress.bonusExercises.{points_scored,points_possible}',
    function() {
      return this.calculatePercentage(
        this.get('sectionProgress.bonusExercises.points_scored'),
        this.get('sectionProgress.bonusExercises.points_possible')
      );
    }
  ),
  pointsBonusScored: computed(
    'sectionProgress.bonusExercises.points_scored',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.bonusExercises.points_scored')
      );
    }
  ),
  pointsBonusPossible: computed(
    'sectionProgress.bonusExercises.points_possible',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.bonusExercises.points_possible')
      );
    }
  ),
  assignmentsAvailable: gt('sectionProgress.mainExercises.exercises_available', 0),
  pointsAssignmentsPercentage: computed(
    'sectionProgress.mainExercises.{points_scored,points_possible}',
    function() {
      return this.calculatePercentage(
        this.get('sectionProgress.mainExercises.points_scored'),
        this.get('sectionProgress.mainExercises.points_possible')
      );
    }
  ),
  pointsAssignmentsScored: computed(
    'sectionProgress.mainExercises.points_scored',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.mainExercises.points_scored')
      );
    }
  ),
  pointsAssignmentsPossible: computed(
    'sectionProgress.mainExercises.points_possible',
    function() {
      return this.formatPoints(
        this.get('sectionProgress.mainExercises.points_possible')
      );
    }
  ),
  itemsVisitedCount: alias('sectionProgress.visits.items_visited'),
  itemsAvailableCount: alias('sectionProgress.visits.items_available'),
  itemVisitsPercentage: alias('sectionProgress.visits.visits_percentage'),
  remainingTime: alias('sectionProgress.timeToComplete'),

  calculatePercentage(scoredPoints, possiblePoints) {
    if (!scoredPoints || !possiblePoints) return 0;
    const percentage = Math.floor((scoredPoints * 100.0) / possiblePoints);
    if (percentage > 100) return 100;
    return percentage;
  },
  formatPoints(points) {
    return points.toFixed(1);
  },
});
