import { getOwner } from '@ember/application';
import Component from '@ember/component';

export default Component.extend({
  classNameBindings: ['isLoading'],

  cancelOnBackgroundClick: true,
  showFooter: true,

  init() {
    this._super(...arguments);

    this.errors = this.errors || [];

    if (this.submitText === undefined) {
      this.submitText = this.get('intl').t('global.submit');
    }

    if (this.cancelText === undefined) {
      this.cancelText = this.get('intl').t('global.cancel');
    }
  },

  didRender() {
    this._super(...arguments);

    // Give the component focus so that it receives keyboard events (needed for closing the modal with ESC)
    this.$().attr({ tabindex: 1 });
    this.$().focus({ preventScroll: true });
  },

  keyUp(event) {
    if (event.keyCode === 27) {
      // 'ESC' key
      this.send('cancel');
      return false; // All other keyup events can be bubbled up
    }
  },

  closeAfterSubmit() {
    this.close();

    // Allow hooking into this process, e.g. to display another modal after submitting this one
    if (this.get('aftersubmit')) {
      this.get('aftersubmit')();
    }
  },

  close() {
    getOwner(this).lookup('controller:application').send('closeModal');

    if (this.get('onclose')) {
      this.get('onclose')();
    }
  },

  actions: {
    submit() {
      this.set('errors', []);

      return this.get('onsubmit')()
        .then(() => {
          this.closeAfterSubmit();
        })
        .catch((errors) => {
          this.set('errors', errors);
        });
    },

    cancel(oncancel = null) {
      oncancel = oncancel || this.get('oncancel');

      if (oncancel) {
        oncancel();
      }

      this.close();
    },
  },
});
