import { computed } from '@ember/object';
import { alias } from '@ember/object/computed';
import Controller from '@ember/controller';

function fieldContainsFilterValue(fieldName, filterName) {
  return applyFilter(filterName, (record, filter) =>
    (record.get(fieldName) || []).some((field) => field === filter)
  );
}

function applyFilter(filterName, filterFn) {
  return function(record) {
    const filter = this.get(filterName);

    return filter === 'all' || filterFn(record, filter);
  };
}

export default Controller.extend({
  filteredDocuments: alias('model.documents'),

  queryParams: [
    'course',
    {
      languageFilter: 'language',
      tagFilter: 'tag',
    },
  ],
  languageFilter: 'all',
  tagFilter: 'all',

  filtered: computed('languageFilter', 'tagFilter', function() {
    return this.get('model.documents')
      .filter(this.hasValidLanguage.bind(this))
      .filter(this.hasValidTag.bind(this));
  }),

  hasValidLanguage: fieldContainsFilterValue('language', 'languageFilter'),
  hasValidTag: fieldContainsFilterValue('tag', 'tagFilter'),
});
