import { computed, observer } from '@ember/object';
import { oneWay } from '@ember/object/computed';
import Controller, { inject as controller } from '@ember/controller';

const AVAILABLE_ORDERS = ['activity', 'age', 'votes'];
const DEFAULT_ORDER = AVAILABLE_ORDERS[0];

const QUERY_PARAMS = ['q', 'tags', 'order', 'page', 'per_page'];

export default Controller.extend({
  queryParams: QUERY_PARAMS,

  q: '',
  tags: '',
  order: DEFAULT_ORDER,
  page: 1,
  per_page: 25,
  section: oneWay('model.section'),

  courseController: controller('course'),

  initialQuery: oneWay('q'),

  isSearching: false,

  filterQuery: computed('order', 'q', 'page', function() {
    const query = [];

    if (this.get('order') !== DEFAULT_ORDER) {
      query.push(
        'question_filter_order=' + encodeURIComponent(this.get('order')),
      );
    }

    if (this.get('q') !== '') {
      query.push(
        'question_search_string=' + encodeURIComponent(this.get('q')),
      );
    }

    if (this.get('page') !== 1) {
      query.push('question_page=' + encodeURIComponent(this.get('page')));
    }

    return query.join('&');
  }),

  selectedTags: computed('model.tags', 'tags', {
    // Return an array of model objects for the tag IDs that are listed (comma-separated) in the query string
    get() {
      const tags = this.get('tags').split(',');
      return this.get('model.tags').filter(
        (tag) => tags.indexOf(tag.get('id')) > -1,
      );
    },
    // ... and vice-versa
    set(k, v) {
      this.set('page', 1);
      this.set('tags', v.map((tag) => tag.get('id')).join(','));
      return v;
    },
  }),

  // Show a loading indicator when any of the query params
  // (that cause the model to be reloaded) changes.
  startSearching: observer(...QUERY_PARAMS, function() {
    this.set('isSearching', true);
  }),

  // And exit the loading state once the model is loaded.
  finishSearching: observer('model', function() {
    this.set('isSearching', false);
  }),

  actions: {
    toPage(page) {
      this.set('page', page);
    },
  },
});
