import Mixin from '@ember/object/mixin';

export default Mixin.create({
  /**
   * Override this variable to set up another polling interval.
   * Defaults to 30000 ms or 30 s.
   */
  pollingInterval: 30000,

  _pollingIntervalInstance: null,

  /**
   * When the route is loaded, we set up an interval timer
   * to periodically refresh the route's model.
   */
  activate() {
    this._super();

    this._pollingIntervalInstance = setInterval(() => {
      this.model().then((model) => this.controller.set('model', model));
    }, this.pollingInterval);
  },

  /**
   * When the route is deactivated, we clean up the timer.
   */
  deactivate() {
    this._super();

    if (this._pollingIntervalInstance) {
      clearInterval(this._pollingIntervalInstance);
      delete this._pollingIntervalInstance;
    }
  },
});
