import { computed } from '@ember/object';
import DS from 'ember-data';
import { every, shuffle } from 'lodash-es';

export default DS.Model.extend({
  text: DS.attr('string'),
  type: DS.attr('string'),
  quizId: DS.attr('string'),
  courseId: DS.attr('string'),
  showSolution: DS.attr('boolean', { defaultValue: false }),
  correctByUser: DS.attr('boolean', { defaultValue: null }),
  count: DS.attr('integer', { defaultValue: 0 }),

  answers: DS.hasMany('answer', { async: false }),

  description: computed('type', function() {
    if (this.get('isMultipleChoiceType')) {
      return this.intl.t('learn.multiple_choice_subtext');
    } else {
      return this.intl.t('learn.multiple_answer_subtext');
    }
  }),

  needsReview: computed('count', function() {
    return this.get('count') > 1 || this.get('correctByUser') === false;
  }),

  reviewPath: computed('quizId', 'courseId', function() {
    const courseId = this.get('courseId');
    const quizId = this.get('quizId');
    return `/learn/review?course_id=${courseId}&quiz_id=${quizId}`;
  }),

  isMultipleChoiceType: computed('type', function() {
    return this.get('type') === 'Xikolo::Quiz::MultipleChoiceQuestion';
  }),

  isMultipleAnswerType: computed('type', function() {
    return this.get('type') === 'Xikolo::Quiz::MultipleAnswerQuestion';
  }),

  // Dynamic attributes for input field
  inputType: computed('type', function() {
    if (this.get('isMultipleChoiceType')) {
      return 'radio';
    } else {
      return 'checkbox';
    }
  }),

  inputName: computed('type', function() {
    if (this.get('isMultipleChoiceType')) {
      return 'options';
    }
  }),

  inputId: computed('type', function() {
    if (this.get('isMultipleChoiceType')) {
      return 'option2';
    }
  }),

  correctAnswersByUser() {
    return every(
      this.get('answers').toArray(),
      (answer) => !answer.get('correct') || answer.get('selected')
    );
  },

  checkUserAnswers() {
    this.set('correctByUser', this.correctAnswersByUser());
  },

  shuffledAnswers: computed('answers.@each.isLoaded', function() {
    return shuffle(this.get('answers').toArray());
  }),

  resetAnswers() {
    this.get('answers').forEach(function(answerItem) {
      answerItem.set('selected', false);
    });
  },
});
