import Service, { inject as service } from '@ember/service';
import moment from 'moment';
import { assign } from 'lodash-es';
import Cookies from 'js-cookie';

export default Service.extend({
  auth: service(),
  store: service(),

  // Used to track events conveniently - Ember style
  track(data) {
    // Not tracking for unauthenticated users
    if (!this.get('auth.loggedIn')) {
      return;
    }

    this.get('store')
      .createRecord('tracking-event', {
        user: {
          uuid: this.get('auth.userID'),
        },
        verb: {
          type: data.verb,
        },
        resource: this.getResource(data),
        timestamp: moment(),
        result: data.result || {},
        context: this.getContext(data),
      })
      .save();
  },

  getResource(data) {
    // TODO: Usage of [data-lanalytics-resource] in DOM tree (first up from the current point, then everywhere)
    return {
      type: data.resourceType,
      uuid: data.resource,
    };
  },

  getContext(data) {
    const context = {};

    // TODO: Usage of [data-lanalytics-context] should be replaced by the internal context stack

    const contextCookie = Cookies.get('lanalytics-context');
    if (window.gon.in_app && contextCookie) {
      assign(context, JSON.parse(contextCookie));
    } else {
      context['user_agent'] = window.navigator && window.navigator.userAgent;
      context['screen_width'] = window.screen && window.screen.width;
      context['screen_height'] = window.screen && window.screen.height;
      if (window.gon.build_version) {
        context['build_version'] = window.gon.build_version;
      }
    }

    // Override all context specified in individual elements
    assign(context, data.context);

    return context;
  },
});
