import $ from 'jquery';
import Service from '@ember/service';

class Feature {
  constructor(value) {
    this.value = value;
  }

  isEnabled() {
    return true;
  }

  is(...values) {
    return values.any((val) => val.toString() === this.value);
  }
}

class DisabledFeature {
  isEnabled() {
    return false;
  }

  is() {
    return false;
  }
}

export default Service.extend({
  init() {
    this._super(...arguments);

    // Load and parse the array of features passed from the backend
    const serializedFeatures = $('meta[name=user-features]').attr('content');
    let features = {};
    try {
      features = JSON.parse(serializedFeatures);
    } catch (e) {
      // If we are unable to parse the JSON, this likely means invalid data was
      // passed from the backend, so we assume there are no enabled features.
    }

    Object.keys(features).map(
      (name) => (features[name] = new Feature(features[name]))
    );

    this.set('features', features);
  },

  feature(name) {
    return this.get('features')[name] || new DisabledFeature();
  },
});
