# frozen_string_literal: true

require 'active_support/cache'

module Xikolo
  module Patches
    module CacheRedisReadonly
      def failsafe(method, returning: nil)
        retryable = true

        super(method, returning:) do
          yield
        rescue ::Redis::ReadOnlyError, ::RedisClient::ReadOnlyError
          if retryable
            redis.respond_to?(:disconnect!) ? redis.disconnect! : redis.reload { nil }
            retryable = false
            retry
          end

          # Let the original implementation decide what to do with the exception
          # On Rails 6.0, it will swallow all errors, incl. command errors.
          # On Rails 5.2, this was only the case for connection-level errors.
          raise
        end
      end

      ::ActiveSupport::Cache::RedisCacheStore.prepend self
    end
  end
end
