# frozen_string_literal: true

module Steps
  module AccountProfile
    Given 'I am on the profile page' do
      visit '/'
      context.with :user do
        page.find('[aria-label="Profile menu"]').click
        click_on 'Profile'
      end
    end

    Given 'there are mandatory profile fields' do
      Rack::Remote.invoke :account, :test_mandatory_profile
    end

    When 'I upload a profile image' do
      page.execute_script("$('#user_visual_upload').removeClass('hide')")
      attach_file 'user_visual_upload', asset_path('profile_image.jpg')
    end

    When 'I fill out the mandatory profile' do
      find('a[data-name=profession]').click
      find('.editable-container input[type="text"]').set 'Master of Disaster'
      find('.editable-container button[type="submit"]').click
    end

    Then 'I see my profile' do
      expect(page).to have_content 'My profile'
    end

    Then 'I see the new profile image' do
      expect(page).to have_xpath "//input[contains(@src, 'avatar')]"
    end

    Then "I see the additional user's primary email address" do
      send 'Given I am logged in'
      send 'Given I am on his user detail page'

      context.with :additional_user do |user|
        expect(page).to have_link(user[:email], href: "mailto:#{user[:email]}", count: 1)
      end
    end

    Then "I do not see the additional user's primary email address" do
      send 'Given I am logged in'
      send 'Given I am on his user detail page'

      context.with :additional_user do |user|
        expect(page).to have_no_link(user[:email])
      end
    end
  end
end

Gurke.configure {|c| c.include Steps::AccountProfile }
