# frozen_string_literal: true

module Steps
  module Helpdesk
    When 'I open the helpdesk' do
      page.find('#helpdesk-button').click
    end

    When 'I follow the link to the helpdesk' do
      click_on 'Go to helpdesk'
    end

    When 'I describe my issue in detail' do
      fill_in 'Title of your issue', with: 'I need help'
      fill_in 'Your Issue', with: 'Where do I find the certificados?'
    end

    When 'I provide an e-mail address' do
      fill_in 'Your e-mail address', with: 'hasso@plattner.de'
    end

    When 'I select the course as ticket category' do
      context.with :course do |course|
        select course['title'], from: 'Category'
      end
    end

    When 'I submit the ticket' do
      click_on 'Report issue'
    end

    Then 'the course should be listed in the category menu' do
      context.with :course do |course|
        expect(page).to have_select 'Category', with_options: [course['title']]
      end
    end

    Then 'the course should be pre-selected in the category menu' do
      context.with :course do |course|
        expect(page).to have_select 'Category', selected: course['title']
      end
    end

    Then 'I should be notified about successful ticket submission' do
      expect(page).to have_content 'Your request has been sent to our support team'
    end

    Then 'an email with my report should be sent to the helpdesk software' do
      open_email fetch_emails(
        to: 'helpdesk@example.com',
        subject: 'I need help'
      ).first

      expect(page).to have_content 'Topic: technical'
      expect(page).to have_content 'certificados'
    end

    Then 'an email with my course-specific report should be sent to the helpdesk software' do
      course = context.fetch(:course)

      open_email fetch_emails(
        to: 'helpdesk@example.com',
        subject: "#{course['course_code']}: I need help"
      ).first

      expect(page).to have_content "Topic: course (#{course['id']})"
      expect(page).to have_content 'certificados'
    end
  end
end

Gurke.configure {|c| c.include Steps::Helpdesk }
