# frozen_string_literal: true

module Steps
  module QuizRecap
    When 'I enter the Quiz Recap page' do
      click_on 'Recap'
    end

    When 'I start a Quiz Recap session' do
      click_on 'Complete (1)'
    end

    When 'I choose the correct answer' do
      check 'The Internet is a global system of interconnected computer networks'
    end

    When 'I choose the wrong answer' do
      check 'The Internet consists of cookies'
    end

    When 'I click review' do
      review_window = window_opened_by do
        click_on 'Review'
      end

      context.assign :review_window, review_window
    end

    Then 'I should see the instructions' do
      expect(page).to have_content 'Here you can practice your knowledge'
      expect(page).to have_content 'Choose a quiz type'
    end

    Then 'I should see a selftest' do
      expect(page).to have_content 'What is the Internet?'
      expect(page).to have_content 'The Internet is a global system of interconnected computer networks'
      expect(page).to have_content 'The Internet consists of cookies'
    end

    Then 'I should see the results page without reviews' do
      expect(page).to have_content 'Quiz completed!'
      expect(page).to_not have_content 'review videos for the following questions'
    end

    Then 'the counter for wrong questions should increase' do
      within('div.question-progress') do
        expect(page).to have_content '1'
      end
      within('div.question-counter') do
        expect(page).to have_content '0 / 1'
      end
    end

    Then 'I should see the results page with reviews' do
      expect(page).to have_content 'Quiz completed!'
      expect(page).to have_content 'review videos for the following questions'
    end

    Then 'I should see the item page in a new window' do
      context.with :review_window, :item do |review_window, item|
        within_window(review_window) do
          expect(page).to have_content item.title
          current_window.close
        end
      end
    end
  end
end

Gurke.configure {|c| c.include Steps::QuizRecap }
