# frozen_string_literal: true

module Steps
  module VideoContent
    def create_pip_stream(attrs = {})
      data = {
        title: 'internetworking_intro_pip',
        provider_video_id: '88330397',
        hd_url: 'https://player.vimeo.com/progressive_redirect/playback/88330397/rendition/720p?loc=external&oauth2_token_id=1212898389&signature=e76af2dc71141d3e7b5a815ce45da4f1bb3390e0fca9edf1d61dc2c2422cb319',
        sd_url: 'https://player.vimeo.com/progressive_redirect/playback/88330397/rendition/360p?loc=external&oauth2_token_id=1212898389&signature=7c9b9023980ebec9bd04902ff4836ebdb77e5204b12046c62e8ef570994370bd',
        hd_download_url: 'https://player.vimeo.com/progressive_redirect/download/88330397/container/4b2a7f28-5b30-44ca-8dd1-038c082776e5/5d8645eb/internetworking2014-w0-pip%20%28720p%29.mp4?expires=1644411648&loc=external&oauth2_token_id=1212898389&signature=0bc8dd8073be49ef4916c1d8bd35365e78ebc568f8e2426d322bb0c3846b47c2',
        sd_download_url: 'https://player.vimeo.com/progressive_redirect/download/88330397/container/4b2a7f28-5b30-44ca-8dd1-038c082776e5/21ad0010/internetworking2014-w0-pip%20%28360p%29.mp4?expires=1644411648&loc=external&oauth2_token_id=1212898389&signature=09f8710c5ad49133f54924ce5cd0f8562d6fae3a8e5aad450971bd10390e3dd7',
        width: 1280, height: 720,
        poster: 'http://b.vimeocdn.com/ts/466/745/466745444_1280.jpg',
        duration: 1678
      }
      data.merge! attrs
      data.compact!

      Server[:video].api.rel(:streams).post(data).value!
    end

    def create_lecturer_stream(attrs = {})
      data = {
        title: 'internetworking_intro_lecturer',
        provider_video_id: '88329527',
        sd_url: 'http://player.vimeo.com/external/88329527.sd.mp4?s=b9a210b4b36ea04dc9b7eb2817f97d5a',
        width: 640, height: 360,
        poster: 'http://b.vimeocdn.com/ts/466/744/466744340_640.jpg'
      }
      data.merge! attrs
      data.compact!

      Server[:video].api.rel(:streams).post(data).value!
    end

    def create_slides_stream(attrs = {})
      data = {
        title: 'internetworking_intro_slides',
        provider_video_id: '88329534',
        hd_url: 'http://player.vimeo.com/external/88329534.hd.mp4?s=548cb245c1e731c8dd931a806bad2ba0',
        sd_url: 'http://player.vimeo.com/external/88329534.sd.mp4?s=6aec28a1654c8b46794c22544a9dbbf7',
        width: 960, height: 720,
        poster: 'http://b.vimeocdn.com/ts/466/744/466744332_960.jpg'
      }
      data.merge! attrs
      data.compact!

      Server[:video].api.rel(:streams).post(data).value!
    end

    def create_video(attrs = {})
      description = <<~TEXT.strip
        Prof. Christoph Meinel introduces basic technical \
        concepts of the World Wide Web from a users perspective.
      TEXT

      data = {
        title: 'WWW Introduction',
        description:,
        lecturer_stream_id: create_lecturer_stream['id'],
        slides_stream_id: create_slides_stream['id'],
      }
      data.merge! attrs
      data.compact!

      Server[:video].api.rel(:videos).post(data).value!
    end

    def create_subtitles(video_id)
      data = {
        id: SecureRandom.uuid,
        video_id:,
        lang: 'en',
        automatic: false,
        vtt: File.read(asset_path('valid_en.vtt')),
      }

      Server[:video].api.rel(:subtitle).post(data).value!
    end

    Given 'a video was created' do
      context.assign :video, create_video
    end

    Given 'a pip stream was created' do
      context.assign :pip_stream, create_pip_stream
    end

    Given 'a lecturer stream was created' do
      context.assign :lecturer_stream, create_lecturer_stream
    end

    Given 'a slides stream was created' do
      context.assign :slides_stream, create_slides_stream
    end

    Given 'streams were created' do
      send :'Given a pip stream was created'
      send :'Given a lecturer stream was created'
      send :'Given a slides stream was created'
    end

    Given 'another set of streams were created' do
      pip_data = {
        title: 'internetworking_intro_pip2',
        provider_video_id: '88330398',
        hd_url: 'https://player.vimeo.com/progressive_redirect/playback/88330398/rendition/720p?loc=external&oauth2_token_id=1212898389&signature=e76af2dc71141d3e7b5a815ce45da4f1bb3390e0fca9edf1d61dc2c2422cb319',
        sd_url: 'https://player.vimeo.com/progressive_redirect/playback/88330398/rendition/360p?loc=external&oauth2_token_id=1212898389&signature=7c9b9023980ebec9bd04902ff4836ebdb77e5204b12046c62e8ef570994370bd',
        hd_download_url: 'https://player.vimeo.com/progressive_redirect/download/88330398/container/4b2a7f28-5b30-44ca-8dd1-038c082776e5/5d8645eb/internetworking2014-w0-pip%20%28720p%29.mp4?expires=1644411648&loc=external&oauth2_token_id=1212898389&signature=0bc8dd8073be49ef4916c1d8bd35365e78ebc568f8e2426d322bb0c3846b47c2',
        sd_download_url: 'https://player.vimeo.com/progressive_redirect/download/88330398/container/4b2a7f28-5b30-44ca-8dd1-038c082776e5/21ad0010/internetworking2014-w0-pip%20%28360p%29.mp4?expires=1644411648&loc=external&oauth2_token_id=1212898389&signature=09f8710c5ad49133f54924ce5cd0f8562d6fae3a8e5aad450971bd10390e3dd7',
      }
      lecturer_data = {
        title: 'internetworking_intro_lecturer2',
        provider_video_id: '88329528',
        sd_url: 'http://player.vimeo.com/external/88329528.sd.mp4?s=b9a210b4b36ea04dc9b7eb2817f97d5a',
      }
      slides_data = {
        title: 'internetworking_intro_slides2',
        provider_video_id: '88329535',
        hd_url: 'http://player.vimeo.com/external/88329535.hd.mp4?s=548cb245c1e731c8dd931a806bad2ba0',
        sd_url: 'http://player.vimeo.com/external/88329535.sd.mp4?s=6aec28a1654c8b46794c22544a9dbbf7',
      }
      context.assign :pip_stream, create_pip_stream(pip_data)
      context.assign :lecturer_stream, create_lecturer_stream(lecturer_data)
      context.assign :slides_stream, create_slides_stream(slides_data)
    end

    Given 'a video item with downloadable content was created' do
      send :'Given streams were created'
      send :'Given I add an item'
      select 'Video', from: 'Type'
      send :'When I fill out the minimal information for video item'
      send :'When I attach downloadable content'
      send :'When I save the video item'
      send :'Then I should be on the course sections page'
    end
  end
end

Gurke.configure {|c| c.include Steps::VideoContent }
