# frozen_string_literal: true

# Start xvfb for real browser in headless environment.

FALSE_ENV_VALUES = %w[0 off false no].freeze

def headless?
  if ENV.key?('HEADLESS')
    FALSE_ENV_VALUES.exclude?(ENV['HEADLESS'])
  elsif ENV.key?('CI')
    FALSE_ENV_VALUES.exclude?(ENV['CI'])
  else
    false
  end
end

if headless?
  require 'headless'

  DIMENSIONS = [1280, 1024].freeze

  headless = Headless.new(dimensions: [*DIMENSIONS, 24].join('x'))
  headless.start
  at_exit { headless.destroy }

  Gurke.configure do |c|
    c.before(:features) do
      Capybara.page.driver.browser.manage.window.move_to 0, 0
      Capybara.page.driver.browser.manage.window.resize_to(*DIMENSIONS)
    end

    c.after(:system) do
      headless.destroy
    end
  end
end
