# frozen_string_literal: true

require 'spec_helper'

describe Group, type: :model do
  subject(:group) { create(:group, name: 'with.game') }

  describe 'validations' do
    describe '#allowed_tags' do
      it { expect(group).to accept_values_for(:tags, [], %w[access custom_recipients]) }
      it { expect(group).not_to accept_values_for(:tags, %w[foo], %w[foo bar]) }
    end
  end

  describe '.prefix' do
    context 'when the query matches available groups' do
      it 'returns matching group' do
        expect(Group.prefix('wit')).to include(group)
      end
    end

    context "when the query doesn't match available groups" do
      it 'returns nothing' do
        expect(Group.prefix('witho')).not_to include(group)
      end
    end

    context "when the query doesn't match at the beginning of the group name" do
      it 'returns nothing' do
        expect(Group.prefix('game')).not_to include(group)
      end
    end
  end
end
