# frozen_string_literal: true

class MembershipsController < ApplicationController
  responders Responders::DecorateResponder,
    Responders::HttpCacheResponder,
    Responders::PaginateResponder

  respond_to :json

  def create
    respond_with Membership.create membership_params
  rescue ActiveRecord::RecordInvalid => e
    respond_with e.record
  end

  def index
    memberships = Membership.joins(:collab_space).where(membership_params)
    if params[:course_id]
      memberships.where!(collab_spaces: {course_id: params[:course_id]})
    end
    memberships.where!(collab_spaces: {kind: params[:kind]}) if params[:kind]

    respond_with memberships
  end

  def update
    respond_with Membership.find(params[:id]).update(membership_params)
  end

  def destroy
    respond_with Membership.find(params[:id]).destroy
  end

  private

  def membership_params
    if params[:learning_room_id].present?
      params[:collab_space_id] = params[:learning_room_id]
    end

    my_params = params.permit :collab_space_id, :user_id, :status
    fixup_string_or_array_value_for_status my_params
    my_params
  end

  # if we want to do where clauses with status: value AND status: [val1, val2]
  # we need string and array values for params, found no qay to tell strong
  # strong params that, so working around it
  def fixup_string_or_array_value_for_status(my_params)
    fix_status = my_params[:status].nil? && params[:status]
    my_params[:status] = params[:status].values if fix_status
  end
end
