# frozen_string_literal: true

class ActivityStreamEvent
  def initialize(key, collab_space, **params)
    @key = key
    @collab_space = collab_space
    @params = params
  end

  def self.from_args(*args)
    new args[0], CollabSpace.find(args[1]), **args[2]
  end

  def to_args
    [@key, @collab_space.id, @params]
  end

  def notify_later!
    ActivityStream::CreateEventJob.perform_later(*to_args)
  end

  def notify!
    Xikolo.api(:notification).value!
      .rel(:events).post(to_json).value!
  end

  def to_json(*_args)
    {
      key: "learning_room.#{@key}",
      payload: final_payload,
      public: false,
      course_id: @collab_space.course_id,
      collab_space_id: @collab_space.id,
      link: @params[:url],
      subscribers: @collab_space.event_subscribers,
    }
  end

  private

  def final_payload
    @params[:payload].clone.tap do |payload|
      %w[new_member ex_member uploader].each do |key|
        if payload.key? :"#{key}_id"
          payload[:"#{key}_name"] = fetch_username(payload[:"#{key}_id"])
        end
      end
    end
  end

  def fetch_username(user_id)
    account_service.rel(:user).get(id: user_id).value!['name']
  end

  def account_service
    @account_service ||= Xikolo.api(:account).value!
  end
end
