# frozen_string_literal: true

class RichtextDecorator < ApplicationDecorator
  delegate :errors

  def fields
    {
      id: object.id,
      text:,
    }
  end

  def as_api_v1(_opts)
    fields.as_json
  end

  def as_event(_opts)
    fields.as_json
  end

  def text
    if context[:raw]
      current_markup = Richtext
        .where(course_id: object.course_id)
        .pluck(:text).join("\n")
      current_markup += "\n#{object.course.description}"
      Xikolo::S3.media_refs(current_markup, public: true) \
        .merge('markup' => object.text)
    else
      Xikolo::S3.externalize_file_refs(object.text, public: true)
    end
  end
end
