# frozen_string_literal: true

class XikoloResultConsumer < Msgr::Consumer
  def create_or_update
    return unless Xikolo.config.learningobjectives['enabled']

    begin
      # 1. Fetch or newly create the result for the item.
      item_result = retrieve_result

      # 2. Save the record or update it if necessary.
      # Depending on that, a completion check might be necessary.
      if item_result.new_record?
        item_result.save!
      elsif update_points?(item_result)
        item_result.update!(visited: true, user_points: achieved_points)
      else
        # No progress update necessary
        return
      end
    rescue ActiveRecord::RecordNotUnique
      retry
    end

    # 3. Update affected progresses of the user's objective including
    # the item for which the result has been created.
    check_completion!
  end

  private

  def item_id
    payload.fetch :item_id
  end

  def user_id
    payload.fetch :user_id
  end

  def context_id
    payload.fetch :course_id
  end

  def timestamp
    payload.fetch :updated_at
  end

  def achieved_points
    payload.fetch(:points, nil).try(:*, 10.0)&.to_i
  end

  def update_points?(item_result)
    # The following check implies that points cannot be subtracted
    !item_result.user_points.try(:>=, achieved_points)
  end

  def retrieve_result
    ItemResult.find_or_initialize_by(
      item_id:,
      user_id:
    ) do |result|
      result.visited = true
      result.user_points = achieved_points
    end
  end

  def check_completion!
    CompletionHandlers.check_completion_for!(
      context: context_id,
      item: item_id,
      user: user_id,
      timestamp:
    )
  end
end
