# frozen_string_literal: true

class XikoloVisitConsumer < Msgr::Consumer
  def create
    return unless Xikolo.config.learningobjectives['enabled']

    begin
      item_result = retrieve_result

      # If an item result exists, the item must have been visited before
      # Therefore, we do not need to check the progress unless it's a
      # newly created item result
      return unless item_result.new_record?

      item_result.save!
    rescue ActiveRecord::RecordNotUnique
      retry
    end

    # 3. Update affected progresses of the user's objectives including
    # the item for which the visit has been created.
    check_completion!
  end

  private

  def item_id
    payload.fetch :item_id
  end

  def user_id
    payload.fetch :user_id
  end

  def context_id
    payload.fetch :course_id
  end

  def timestamp
    payload.fetch :created_at
  end

  def retrieve_result
    ItemResult.find_or_initialize_by(
      item_id:,
      user_id:
    ) do |result|
      result.visited = true
    end
  end

  def check_completion!
    CompletionHandlers.check_completion_for!(
      context: context_id,
      item: item_id,
      user: user_id,
      timestamp:
    )
  end
end
