# frozen_string_literal: true

class ObjectivesController < RESTController
  respond_to :json

  has_scope :context_id do |_controller, scope, value|
    scope.for_context value.to_s
  end

  rfc6570_params index: %i[context_id embed]

  def index
    respond_with collection, embed:
  end

  def create
    objective = Objective.create objective_params

    if params[:learning_units]
      objective.update_learning_units(
        learning_unit_params.fetch(:learning_units)
      )
    end

    respond_with objective
  end

  def update
    Objective.transaction do
      resource.update(objective_params)
      if params[:learning_units]
        resource.update_learning_units(
          learning_unit_params.fetch(:learning_units)
        )
      end
    end

    respond_with resource
  end

  def show
    respond_with resource, embed:
  end

  def destroy
    respond_with resource.destroy
  end

  private

  def objective_params
    params.permit(
      :context_id,
      :title,
      :description,
      :position,
      :completion_type,
      :final
    ).to_h
  end

  def learning_unit_params
    params.permit(
      learning_units: [
        :id,
        {knowledge_acquisition_items: [],
        knowledge_examination_items: []},
      ]
    ).to_h.symbolize_keys
  end

  def embed
    params[:embed].to_s.split(',').map(&:strip)
  end
end
