# frozen_string_literal: true

class UserObjectivesController < RESTController
  respond_to :json

  has_scope :user_id do |_controller, scope, value|
    scope.for_user value.to_s
  end

  has_scope :objective_id do |_controller, scope, value|
    scope.for_objective value.to_s
  end

  has_scope :context_id do |_controller, scope, value|
    scope.for_context value.to_s
  end

  has_scope :active, type: :boolean

  rfc6570_params index: %i[user_id objective_id context_id active]

  def index
    respond_with collection
  end

  def create
    user_objective = UserObjective
      .create_with(user_objective_params)
      .find_or_initialize_by(
        user_id: params.require(:user_id),
        objective_id: params.require(:objective_id)
      ).tap do |uo|
      uo.activate_with!(user_objective_params)
    end

    respond_with user_objective
  rescue ActiveRecord::RecordNotUnique
    retry
  end

  def update
    resource.update user_objective_params
    respond_with resource
  end

  def show
    respond_with resource
  end

  private

  def user_objective_params
    params.permit :user_id, :objective_id, :active, :completed_at
  end
end
