# frozen_string_literal: true

class UserStatusesController < RESTController
  respond_to :json

  has_scope :user_id do |_controller, scope, value|
    scope.for_user value.to_s
  end

  has_scope :context_id do |_controller, scope, value|
    scope.for_context value.to_s
  end

  rfc6570_params index: %i[user_id context_id embed]

  def index
    respond_with collection, embed:
  end

  def create
    user_status = UserStatus
      .create_with(user_status_params)
      .find_or_initialize_by(
        user_id: params.require(:user_id),
        context_id: params.require(:context_id)
      ).tap do |us|
      us.update!(user_status_params)
    end

    respond_with user_status, embed:
  rescue ActiveRecord::RecordNotUnique
    retry
  end

  def update
    resource.settings = resource.settings.merge(params[:settings].permit!)
    resource.save!

    respond_with resource
  end

  def show
    respond_with resource
  end

  private

  def user_status_params
    params
      .permit(:user_id, :context_id)
      .merge(params.to_unsafe_hash.slice(:settings))
  end

  def embed
    params[:embed].to_s.split(',').map(&:strip)
  end
end
