# frozen_string_literal: true

class LearningUnitDecorator < ApplicationDecorator
  delegate_all
  decorates_association :knowledge_acquisition_items
  decorates_association :knowledge_examination_items

  def as_json(opts = {})
    @opts = opts
    {**fields, **links}
  end

  protected

  def fields
    {
      id:,
      objective_id:,
      knowledge_acquisition_items:,
      knowledge_examination_items:,
      priority:,
    }
  end

  def links
    {
      url: h.learning_unit_url(object),
      objective_url: h.objective_rfc6570.partial_expand(id: objective_id),
    }.tap do |attrs|
      unless @opts[:collection]
        if lower_learning_unit_id
          attrs[:prev_learning_unit_url] = h.learning_unit_rfc6570.expand(id: lower_learning_unit_id)
        end
        if higher_learning_unit_id
          attrs[:next_learning_unit_url] = h.learning_unit_rfc6570.expand(id: higher_learning_unit_id)
        end
      end
    end
  end
end
