# frozen_string_literal: true

class ObjectiveDecorator < ApplicationDecorator
  delegate_all
  decorates_association :learning_units

  def as_json(opts = {})
    @opts = opts
    {**fields, **links}.tap do |attrs|
      attrs[:details] = details_minutes if embed? 'details'
      attrs[:learning_units] = learning_units if embed? 'learning_units'
    end
  end

  protected

  def fields
    {
      id:,
      context_id:,
      title:,
      description:,
      position:,
      completion_type:,
      final:,
    }
  end

  def links
    {
      url: h.objective_url(object),
      learning_units_url: h.learning_units_rfc6570.partial_expand(objective_id: id),
      user_objectives_url: h.user_objectives_rfc6570.partial_expand(objective_id: id),
    }.tap do |attrs|
      if !context[:collection] && parent_objective_id
        attrs[:parent_objective_url] = h.objective_url(parent_objective_id)
      end
    end
  end

  def embed?(obj)
    @opts&.key?(:embed) && @opts[:embed].include?(obj)
  end
end
