# frozen_string_literal: true

class UserObjectiveDecorator < ApplicationDecorator
  delegate_all
  decorates_association :progress

  def as_json(_opts = {})
    {
      **fields,
      **links,
      progress:,
    }
  end

  def as_event(_opts = {})
    fields
  end

  protected

  def fields
    {
      id:,
      user_id:,
      objective_id:,
      active:,
      created_at: created_at&.iso8601,
      completed_at: completed_at&.iso8601,
    }
  end

  def links
    {
      url: h.user_objective_url(object),
      objective_url: h.objective_rfc6570.partial_expand(id: objective_id),
    }
  end
end
