# frozen_string_literal: true

class UserStatusDecorator < ApplicationDecorator
  delegate_all
  decorates_association :user_objectives

  def as_json(opts = {})
    @opts = opts
    {**fields, **links}.tap do |attrs|
      attrs[:user_objectives] = user_objectives if embed? 'user_objectives'
    end
  end

  def as_event(_opts = {})
    fields
  end

  protected

  def fields
    {
      id:,
      user_id:,
      context_id:,
      settings:,
    }
  end

  def links
    {
      url: h.user_status_url(object),
    }
  end

  def embed?(obj)
    @opts&.key?(:embed) && @opts[:embed].include?(obj)
  end
end
