# frozen_string_literal: true

module CompletionHandlers
  class << self
    def resolve(name)
      raise 'Unknown completion type' unless all.include?(name.camelize)

      "CompletionHandlers::#{name.camelize}".constantize
    end

    def all
      @all ||= supported_completion_types.map(&:camelize).freeze
    end

    def supported_completion_types
      @supported_completion_types ||= Rails.root
        .join('app/models/completion_handlers')
        .to_enum(:each_child)
        .map {|i| i.basename.to_s.split('.').first }
        .select {|handler| valid_completion_handler?(handler) }
        .sort
        .freeze
    end

    def handler_objective_items_status
      @handler_objective_items_status ||= supported_completion_types
        .index_with do |type|
        resolve(type).requires_objective_items?
      end.freeze
    end

    def check_completion_for!(context:, item: nil, user: nil, timestamp: nil)
      objectives = affected_objectives(context, item)
      user_objectives = UserObjective.for_objective objectives.pluck(:id)
      user_objectives = user_objectives.for_user(user) if user.present?
      user_objectives.find_each do |u|
        u.check_completion! timestamp:
      end
    end

    def affected_objectives(context, item)
      objectives = Objective.for_context(context)
      if item.present?
        objectives = objectives.select do |o|
          !requires_objective_items?(o) || o.items.pluck(:id).include?(item)
        end
      end
      objectives
    end

    def requires_objective_items?(objective)
      handler_objective_items_status[objective.completion_type]
    end

    private

    ABSTRACT_COMPLETION_HANDLERS = %w[base xikolo_item_helper].freeze

    def valid_completion_handler?(handler)
      ABSTRACT_COMPLETION_HANDLERS.exclude?(handler)
    end
  end
end
