# frozen_string_literal: true

module CompletionHandlers
  class Base
    include XikoloItemHelper

    class << self
      # rubocop:disable Naming/MemoizedInstanceVariableName
      def requires_objective_items!
        @requires_items = true
      end

      def requires_objective_items?
        @requires_items ||= false
      end
      # rubocop:enable Naming/MemoizedInstanceVariableName
    end

    attr_reader :user_objective, :objective

    def initialize(user_objective)
      @user_objective = user_objective
      @objective = user_objective.objective

      @completed = nil
    end

    def completed?
      return @completed unless @completed.nil?

      check_completion!
      @completed
    end

    def set_progress!
      user_objective.progress.update!(
        points_progress: {
          points_scored: progress[:points_scored].try(:fdiv, 10),
          points_possible: progress[:points_possible].try(:fdiv, 10),
          points_percentage: progress[:points_percentage],
        }.compact,
        visit_progress: {
          items_visited: progress[:items_visited],
          items_available: progress[:items_available],
          visit_percentage: progress[:visit_percentage],
        }.compact,
        achievable: achievable?
      )
    end

    protected

    def check_completion!
      raise NotImplementedError('Method must be implemented in the subclass!')
    end

    def progress
      raise NotImplementedError('Method must be implemented in the subclass!')
    end

    def achievable?
      raise NotImplementedError('Method must be implemented in the subclass!')
    end

    def completed!
      @completed = true
    end
  end
end
