# frozen_string_literal: true

module CompletionHandlers
  class XikoloCourseCompletion < Base
    def check_completion!
      completed! if points_percentage >= points_percentage_threshold
    end

    def progress
      @progress ||= {
        points_scored: scored_points,
        points_possible: max_points,
        # Percentage of achieved points w.r.t. total points
        points_percentage:,
        items_visited: item_visits.size,
        items_available: available_course_items.size,
        visit_percentage:,
      }
    end

    def achievable?
      return true if completed?
      return true if max_points.zero?

      # Remaining exercises (main & bonus) are sufficient to reach threshold
      return true if points_achievable?

      false
    end

    private

    def user_results
      @user_results ||= results_for(course_items.pluck(:id))
    end

    ## Visits ##
    def visit_percentage
      # Currently, we are considering visits for quizzes although the deadline
      # might have passed. This is consistent with the Xikolo course service
      # implementation and the Xikolo CoP's issuing rule.
      visit_percentage_for(item_visits, available_course_items)
    end

    ## Points ##
    def main_exercises
      @main_exercises ||= by_exercise_type(course_items, ['main'])
    end

    def bonus_exercises
      @bonus_exercises ||= by_exercise_type(course_items, ['bonus'])
    end

    def scored_points_items
      main_exercises + bonus_exercises
    end

    def max_points_items
      # max_points are determined with regard to
      # the maximal points of the main exercises.
      main_exercises
    end
  end
end
