# frozen_string_literal: true

module CompletionHandlers
  class XikoloCourseExploration < Base
    def check_completion!
      completed! if visit_percentage >= visit_percentage_threshold
    end

    def progress
      @progress ||= {
        items_visited: item_visits.size,
        items_available: available_course_items.size,
        visit_percentage:,
      }
    end

    def achievable?
      # Achievable when visits are possible, i.e., unless items are locked OR
      # submission deadline has passed. Currently, always true since "expired"
      # items do not count for the progress and quizzes with deadline passed
      # count for visits (same policy as in Xikolo).

      true
    end

    private

    def user_results
      @user_results ||= results_for(course_items.pluck(:id))
    end

    def visit_percentage
      # Currently, we are considering visits for quizzes although the deadline
      # might have passed. This is consistent with the Xikolo course service
      # implementation and the Xikolo CoP's issuing rule.
      @visit_percentage ||= visit_percentage_for(
        item_visits,
        available_course_items
      )
    end
  end
end
