# frozen_string_literal: true

class Item < ApplicationRecord
  self.table_name = 'objectives_items'

  validates :item_type, presence: {message: 'required'}

  scope :for_context, ->(context) { where(context_id: context) }
  scope :for_course, ->(course) { where("meta->>'course_id' = ?", course) }

  has_many :knowledge_acquisitions
  has_many :knowledge_examinations

  has_many :knowledge_acquisition_units,
    through: :knowledge_acquisitions,
    source: :learning_unit,
    dependent: :delete_all
  has_many :knowledge_examination_units,
    through: :knowledge_examinations,
    source: :learning_unit,
    dependent: :delete_all
  has_many :item_results, dependent: :delete_all
end
