# frozen_string_literal: true

class ItemResult < ApplicationRecord
  validates :item_id, uniqueness: {scope: :user_id}
  validates :user_points,
    numericality: {only_integer: true,
                   allow_nil: true,
                   message: 'invalid_format'}

  scope :for_item, ->(item) { where item_id: item }
  scope :for_user, ->(user) { where user_id: user }

  # We want to track the results even if no item exists
  # in case the item creation is delayed
  belongs_to :item, optional: true

  def visited?
    visited
  end

  def points?
    user_points.present?
  end
end
