# frozen_string_literal: true

class LearningUnit < ApplicationRecord
  scope :for_objective, ->(objective) { where objective_id: objective }

  has_many :knowledge_acquisitions
  has_many :knowledge_examinations

  has_many :knowledge_acquisition_items,
    through: :knowledge_acquisitions,
    source: :item,
    dependent: :delete_all
  has_many :knowledge_examination_items,
    through: :knowledge_examinations,
    source: :item,
    dependent: :delete_all
  belongs_to :objective
  acts_as_list scope: :objective, column: :priority

  default_scope do
    includes(:knowledge_acquisition_items, :knowledge_examination_items)
  end

  def higher_learning_unit_id
    lower_item&.id
  end

  def lower_learning_unit_id
    higher_item&.id
  end
end
