# frozen_string_literal: true

class UserStatus < ApplicationRecord
  include Notify

  validates :user_id, :context_id, presence: {message: 'required'}
  validates :user_id,
    uniqueness: {scope: :context_id, message: 'only one per context'}

  scope :for_user, ->(user) { where user_id: user }
  scope :for_context, ->(context) { where context_id: context }

  def user_objectives
    UserObjective.for_user(user_id).for_context(context_id)
  end
end
