# frozen_string_literal: true

# This file should contain all the record creation needed to seed the database with its default values.
# The data can then be loaded with the rake db:seed (or created alongside the db with db:setup).
#
# Examples:
#
#   cities = City.create([{ name: 'Chicago' }, { name: 'Copenhagen' }])
#   Mayor.create(name: 'Emanuel', city: cities.first)

user_id1 = '00000001-3100-4444-9999-000000000002'
user_id2 = '00000001-3100-4444-9999-000000000003'
geo2013 = '00000001-3300-4444-9999-000000000002'
cloud2013 = '00000001-3300-4444-9999-000000000001'

Objective.skip_callback :commit, :after, :update_user_objectives!
UserObjective.skip_callback :create, :after, :check_completion!

objective_course = Objective.create!(
  title: 'Complete the course (Record of Achievement)',
  description: 'Complete the course and receive a Record of Achievement.',
  context_id: geo2013,
  position: 1,
  completion_type: 'xikolo_course_completion',
  id: '00000001-6400-4444-9999-000000000001'
)

Objective.create!(
  title: 'Explore the course (Confirmation of Participation)',
  description: 'Explore the course and receive a Certificate of Participation.',
  context_id: geo2013,
  position: 2,
  completion_type: 'xikolo_course_exploration',

  id: '00000001-6400-4444-9999-000000000002'
)

objective_geo = Objective.create!(
  title: 'Topic 1: Geovisualization',
  description: 'Learn about Geovisualization.',
  context_id: geo2013,
  position: 3,
  completion_type: 'xikolo_topic_completion',
  id: '00000001-6400-4444-9999-000000000003'
)

objective_clouds = Objective.create!(
  title: 'Topic 1: Cloud',
  description: 'Learn about Clouds.',
  context_id: cloud2013,
  position: 1,
  completion_type: 'xikolo_topic_completion',
  id: '00000001-6400-4444-9999-000000000004'
)

learning_unit1 = LearningUnit.create!(
  objective: objective_course,
  priority: 1,
  id: '00000002-6400-5555-9999-000000000001'
)

learning_unit2 = LearningUnit.create!(
  objective: objective_geo,
  priority: 1,
  id: '00000002-6400-5555-9999-000000000002'
)

learning_unit3 = LearningUnit.create!(
  objective: objective_clouds,
  priority: 1,
  id: '00000002-6400-5555-9999-000000000003'
)

item1 = Item.create!(
  id: '00000003-3100-4444-9999-000000000009',
  item_type: 'video',
  time_effort: 131,
  meta: {
    course_id: cloud2013,
    section_id: '00000002-3100-4444-9999-000000000007',
  }
)

item2 = Item.create!(
  id: '00000003-3100-4444-9999-000000000010',
  item_type: 'video',
  time_effort: 1424,
  meta: {
    course_id: cloud2013,
    section_id: '00000002-3100-4444-9999-000000000007',
  }
)

item3 = Item.create!(
  id: '00000003-3100-4444-9999-000000000002',
  item_type: 'video',
  time_effort: 600,
  meta: {
    course_id: cloud2013,
    section_id: '00000002-3100-4444-9999-000000000001',
  }
)

item4 = Item.create!(
  id: '00000003-3100-4444-9999-000000000005',
  item_type: 'quiz',
  time_effort: 600,
  meta: {
    course_id: cloud2013,
    section_id: '00000002-3100-4444-9999-000000000001',
    exercise_type: 'selftest',
  }
)

learning_unit1.knowledge_acquisition_items << [item1, item2]
learning_unit2.knowledge_acquisition_items << item2
learning_unit3.knowledge_acquisition_items << item3
learning_unit3.knowledge_examination_items << item4

UserObjective.create!(
  objective_id: objective_course.id,
  user_id: user_id1,
  active: true
)

UserObjective.create!(
  objective_id: objective_course.id,
  user_id: user_id2,
  active: true
)

UserStatus.create!(
  user_id: user_id1,
  context_id: objective_course.context_id,
  settings: {display_objective_selection: true}
)

Objective.set_callback :commit, :after, :update_user_objectives!
UserObjective.set_callback :create, :after, :check_completion!
