# frozen_string_literal: true

require 'rails_helper'

RSpec.describe LearningUnitDecorator, type: :decorator do
  let(:objective) { create(:objective) }
  let(:learning_unit) { create(:learning_unit, objective:) }
  let(:decorator) { learning_unit.decorate }

  describe 'as_json' do
    subject(:the_learning_unit) { decorator.as_json.stringify_keys }

    it 'serializes resource as JSON' do
      expect(the_learning_unit).to include(
        'id' => learning_unit.id,
        'objective_id' => objective.id,
        'knowledge_acquisition_items' => [],
        'knowledge_examination_items' => [],
        'priority' => 1,
        'url' => learning_unit_url(learning_unit)
      )
    end

    context 'with items' do
      let(:item) { create(:item) }
      let(:learning_unit) { create(:learning_unit, objective:, knowledge_acquisitions: [item]) }

      it 'serializes resource as JSON' do
        expect(the_learning_unit).to include(
          'id' => learning_unit.id,
          'objective_id' => objective.id,
          'knowledge_acquisition_items' => [ItemDecorator.decorate(item)],
          'knowledge_examination_items' => [],
          'priority' => 1,
          'url' => learning_unit_url(learning_unit)
        )
      end
    end
  end
end
