# frozen_string_literal: true

require 'rails_helper'

RSpec.describe ObjectiveDecorator, type: :decorator do
  let(:objective) { create(:objective) }
  let(:decorator) { objective.decorate }
  let(:opts) { {} }

  context 'as_json' do
    subject(:the_objective) { decorator.as_json(opts).stringify_keys }

    it 'includes expected keys' do
      expect(the_objective.keys).to match_array %w[
        id
        context_id
        title
        description
        position
        completion_type
        final
        url
        learning_units_url
        user_objectives_url
      ]
    end

    it 'serializes resource as JSON' do
      expect(the_objective).to include(
        'id' => objective.id,
        'context_id' => objective.context_id,
        'title' => objective.title,
        'description' => objective.description,
        'final' => objective.final,
        'position' => 1,
        'url' => objective_url(objective)
      )
    end

    context 'w/ embedded details' do
      let(:opts) { super().merge embed: 'details' }

      it 'serializes resource as JSON' do
        expect(the_objective).to include(
          'id' => objective.id,
          'context_id' => objective.context_id,
          'title' => objective.title,
          'description' => objective.description,
          'final' => objective.final,
          'details' => [],
          'position' => 1,
          'url' => objective_url(objective)
        )
      end
    end

    context 'w/ embedded learning_units' do
      let!(:learning_unit) { create(:learning_unit, objective:) }
      let(:opts) { super().merge embed: 'learning_units' }

      it 'serializes resource as JSON' do
        expect(the_objective).to include(
          'id' => objective.id,
          'context_id' => objective.context_id,
          'title' => objective.title,
          'description' => objective.description,
          'final' => objective.final,
          'position' => 1,
          'learning_units' => [learning_unit.decorate],
          'url' => objective_url(objective)
        )
      end
    end
  end
end
