# frozen_string_literal: true

require 'rails_helper'

RSpec.describe UserStatusDecorator, type: :decorator do
  let(:user_status) { create(:user_status) }
  let(:decorator) { user_status.decorate }
  let(:opts) { {} }

  context 'as_json' do
    subject(:the_user_status) { decorator.as_json(opts).stringify_keys }

    it 'serializes resource as JSON' do
      expect(the_user_status).to include(
        'id' => user_status.id,
        'user_id' => user_status.user_id,
        'context_id' => user_status.context_id,
        'settings' => user_status.settings,
        'url' => user_status_url(user_status)
      )
    end

    context 'w/ embedded user objectives' do
      let(:opts) { super().merge embed: 'user_objectives' }

      context 'w/o user objective' do
        it 'serializes resource as JSON' do
          expect(the_user_status).to include(
            'id' => user_status.id,
            'user_id' => user_status.user_id,
            'context_id' => user_status.context_id,
            'settings' => user_status.settings,
            'user_objectives' => [],
            'url' => user_status_url(user_status)
          )
        end
      end

      context 'w/ user objective' do
        let!(:objective) { create(:objective) }
        let!(:user_status) { create(:user_status, context_id: objective.context_id) }
        let!(:user_objective) { create(:user_objective, objective_id: objective.id, user_id: user_status.user_id) }

        it 'serializes resource as JSON' do
          expect(the_user_status).to include(
            'id' => user_status.id,
            'user_id' => user_status.user_id,
            'context_id' => user_status.context_id,
            'settings' => user_status.settings,
            'user_objectives' => [user_objective.decorate],
            'url' => user_status_url(user_status)
          )
        end
      end
    end
  end
end
