# frozen_string_literal: true

require 'securerandom'

FactoryBot.define do
  sequence :uuid do
    UUID4(SecureRandom.uuid)
  end

  factory :item do
    item_type { 'video' }
    meta { {} }

    trait :with_time_effort do
      time_effort { 40 }
    end

    trait :with_meta do
      meta { {course_id: '00000002-3100-4444-9999-000000000001'} }
    end
  end

  factory :objective do
    parent_objective_id { nil }
    context_id { '00000002-3100-4444-9999-000000000001' }
    sequence(:title) {|n| "Objective ##{n}" }
    sequence(:description) {|n| "This is the description for objective ##{n}" }
    position { 1 }
    completion_type { 'xikolo_course_completion' }
    final { false }
  end

  factory :user_status do
    user_id { '00000001-3100-4444-9999-000000000001' }
    context_id { '00000002-3100-4444-9999-000000000001' }
    settings { {} }
  end

  factory :learning_unit do
    objective
    priority { 1 }
    transient do
      knowledge_acquisitions { [] }
      knowledge_examinations { [] }
    end

    after :create do |learning_unit, options|
      learning_unit.knowledge_acquisition_items << options.knowledge_acquisitions
      learning_unit.knowledge_examination_items << options.knowledge_examinations
    end
  end

  factory :knowledge_acquisition do
    learning_unit
    item
  end

  factory :knowledge_examination do
    learning_unit
    item
  end

  factory :user_objective do
    objective
    user_id { '00000001-3100-4444-9999-000000000001' }
    active { true }
    completed_at { nil }

    before :create do |user_objective|
      user_objective.class.skip_callback :create, :after, :check_completion!
    end

    after :create do |user_objective|
      user_objective.class.set_callback :create, :after, :check_completion!
    end

    trait :inactive do
      active { false }
    end

    trait :completed do
      completed_at { 1.day.ago }
    end
  end

  factory :progress do
    user_objective
    points_progress { {} }
    visit_progress { {} }
    achievable { true }
  end

  factory :item_result do
    item
    user_id { '00000001-3100-4444-9999-000000000001' }
    visited { false }
    user_points { nil }

    trait :visited do
      visited { true }
    end

    trait :with_points do
      user_points { 50 }
    end
  end
end
