# frozen_string_literal: true

require 'rails_helper'

RSpec.describe CompletionHandlers::Base, type: :model do
  let(:objective) { create(:objective) }
  let(:user_objective) { create(:user_objective, objective:) }
  let(:handler) { described_class.new user_objective }

  describe '#initialize' do
    it 'initializes the completed status correctly' do
      expect(handler.instance_variable_get(:@completed)).to be_nil
    end
  end

  describe '#completed?' do
    subject(:call_completed) { handler.completed? }

    context 'w/o completion status calculated' do
      it 'triggers the completion check' do
        expect(handler).to receive(:check_completion!).once.with no_args
        call_completed
      end
    end

    context 'w/ completion status calculated' do
      it 'does not trigger the completion check when completed' do
        handler.instance_variable_set :@completed, true
        expect(handler).not_to receive :check_completion!
        call_completed
      end

      it 'does not trigger the completion check when not completed' do
        handler.instance_variable_set :@completed, false
        expect(handler).not_to receive :check_completion!
        call_completed
      end
    end
  end
end
