# frozen_string_literal: true

require 'rails_helper'

RSpec.describe 'Objective: Index', type: :request do
  subject(:list_objectives) { api.rel(:objectives).get(attrs).value! }

  let(:api) { Restify.new(:test).get.value! }
  let(:objective) { create(:objective, context_id: '00000002-3100-5555-9999-000000000001', position: 1) }
  let(:objective_2) { create(:objective, context_id: '00000002-3100-6666-9999-000000000002', position: 1) }
  let(:attrs) { {context_id: objective.context_id} }

  before do
    # Ensure that the objectives exist
    objective
    objective_2
  end

  context 'w/ context filter' do
    context 'includes details' do
      it 'returns one objective' do
        expect(list_objectives.size).to eq 1
      end

      it 'returns objective resource' do
        expect(list_objectives.first.to_h).to include \
          'id' => objective.id,
          'context_id' => attrs[:context_id],
          'title' => objective.title,
          'description' => objective.description,
          'completion_type' => objective.completion_type,
          'final' => objective.final,
          'url' => objective_url(objective)
      end
    end
  end

  context 'w/ embed parameter' do
    let(:attrs) { super().merge embed: 'details' }

    context 'includes details' do
      it 'returns one objective' do
        expect(list_objectives.size).to eq 1
      end

      it 'returns objective resource with details' do
        expect(list_objectives.first.to_h).to include \
          'id' => objective.id,
          'context_id' => attrs[:context_id],
          'title' => objective.title,
          'description' => objective.description,
          'completion_type' => objective.completion_type,
          'final' => objective.final,
          'details' => [],
          'url' => objective_url(objective)
      end
    end
  end

  context '(result order)' do
    subject(:list_objectives) { api.rel(:objectives).get.value! }

    let!(:objective_3) { create(:objective, context_id: '00000002-3100-6666-9999-000000000001', position: 2) }

    it 'returns the objectives in the correct order' do
      expect(list_objectives.pluck('id')).to eq [objective, objective_3, objective_2].map(&:id)
    end
  end
end
