# frozen_string_literal: true

require 'rails_helper'

RSpec.describe 'Objective: Update', type: :request do
  subject(:update_objective) { api.rel(:objective).patch(attrs, id: objective.id).value! }

  let(:api) { Restify.new(:test).get.value! }
  let(:title) { 'First Objective Title' }
  let(:objective) { create(:objective, title:) }
  let(:attrs) do
    {
      title: 'Any Objective',
      final: true,
    }
  end

  it 'returns the updated objective resource' do
    expect(update_objective.to_h).to include \
      'id' => objective.id,
      'context_id' => objective.context_id,
      'title' => attrs[:title],
      'description' => objective.description,
      'completion_type' => objective.completion_type,
      'final' => attrs[:final]
  end

  context 'w/ learning units param' do
    let(:item_1) { create(:item) }
    let(:item_2) { create(:item) }
    let(:attrs) do
      super().merge(
        'learning_units' => [{
          'id' => nil,
          'knowledge_acquisition_items' => [item_1.id],
          'knowledge_examination_items' => [item_2.id],
        }]
      )
    end

    it 'updates the learning units' do
      expect do
        update_objective
      end.to change { item_1.knowledge_acquisition_units.count }.from(0).to(1)
        .and change { item_2.knowledge_examination_units.count }.from(0).to(1)
        .and change(LearningUnit, :count).from(0).to(1)
    end
  end
end
