# frozen_string_literal: true

require 'rails_helper'

RSpec.describe 'Progress: Index', type: :request do
  subject(:list_progresses) { api.rel(:progresses).get(attrs).value! }

  let(:api) { Restify.new(:test).get.value! }
  let(:user_id_1) { '00000001-3100-4444-9999-000000000001' }
  let(:user_id_2) { '00000001-3100-4444-9999-000000000002' }
  let(:user_objective_1) { create(:user_objective, :inactive, user_id: user_id_1) }
  let(:user_objective_2) { create(:user_objective, user_id: user_id_2) }
  let(:progress_1) { user_objective_1.progress }
  let(:progress_2) { user_objective_2.progress }
  let(:attrs) { {user_objective_id: user_objective_1.id} }

  before do
    # Ensure the second user objective exists
    user_objective_2
  end

  context 'w/ user objective filter' do
    it 'returns one progress' do
      expect(list_progresses.size).to eq 1
    end

    it 'returns progress resource for user objective' do
      expect(list_progresses.first.to_h).to include \
        'id' => progress_1.id,
        'user_objective_id' => attrs[:user_objective_id],
        'points_progress' => progress_1.points_progress,
        'visit_progress' => progress_1.visit_progress,
        'achievable' => progress_1.achievable,
        'url' => progress_url(progress_1)
    end
  end

  context 'w/ user filter' do
    let(:attrs) { {user_id: user_objective_1.user_id} }

    it 'returns one progress' do
      expect(list_progresses.size).to eq 1
    end

    it 'returns progress resource for user' do
      expect(list_progresses.first.to_h).to include \
        'id' => progress_1.id,
        'user_objective_id' => user_objective_1.id,
        'points_progress' => progress_1.points_progress,
        'visit_progress' => progress_1.visit_progress,
        'achievable' => progress_1.achievable,
        'url' => progress_url(progress_1)
    end
  end
end
