# frozen_string_literal: true

require 'rails_helper'

RSpec.describe 'UserObjective: Index', type: :request do
  subject(:list_user_objectives) { api.rel(:user_objectives).get(attrs).value! }

  let(:api) { Restify.new(:test).get.value! }
  let(:objective) { create(:objective, context_id: '00000002-3100-5555-9999-000000000001') }
  let(:objective_2) { create(:objective, context_id: '00000002-3100-6666-9999-000000000002') }
  let(:user_objective) { create(:user_objective, :inactive, objective:) }
  let(:user_objective_2) { create(:user_objective, objective: objective_2) }
  let(:attrs) { {context_id: objective.context_id} }

  before do
    # Ensure the user objectives exist
    user_objective
    user_objective_2
  end

  context 'w/ context filter' do
    it 'returns one user objective' do
      expect(list_user_objectives.size).to eq 1
    end

    it 'returns user objective resource with objective in requested context' do
      expect(list_user_objectives.first.to_h).to include \
        'id' => user_objective.id,
        'objective_id' => user_objective.objective_id,
        'user_id' => user_objective.user_id,
        'active' => user_objective.active,
        'created_at' => user_objective.created_at.iso8601,
        'completed_at' => user_objective.completed_at,
        'url' => user_objective_url(user_objective)
    end
  end
end
