# frozen_string_literal: true

require 'rails_helper'

RSpec.describe 'UserStatus: Index', type: :request do
  subject(:list_user_status) { api.rel(:user_statuses).get(attrs).value! }

  let(:api) { Restify.new(:test).get.value! }
  let(:user_status) { create(:user_status) }

  before do
    # Ensure the user status exists
    user_status
  end

  context 'w/ embed parameter' do
    let(:attrs) { {embed: 'user_objectives'} }

    context 'includes user status' do
      it 'returns one user status' do
        expect(list_user_status.size).to eq 1
      end

      it 'returns user status resource with user objectives' do
        expect(list_user_status.first.to_h).to include \
          'id' => user_status.id,
          'user_id' => user_status.user_id,
          'context_id' => user_status.context_id,
          'settings' => user_status.reload.settings,
          'user_objectives' => [],
          'url' => user_status_url(user_status)
      end
    end
  end
end
