# frozen_string_literal: true

require 'rails_helper'

RSpec.describe 'UserStatus: Update', type: :request do
  subject(:update_user_status) { api.rel(:user_status).patch(attrs, id: user_status.id).value! }

  let(:api) { Restify.new(:test).get.value! }
  let(:user_status) { create(:user_status, settings: {some_setting: 'true'}) }
  let(:attrs) { {settings: {new_setting: 'false'}} }

  context 'w/ new setting' do
    it 'returns updated user status' do
      expect(update_user_status.to_h).to include \
        'id' => user_status.id,
        'user_id' => user_status.user_id,
        'context_id' => user_status.context_id,
        'settings' => user_status.reload.settings,
        'url' => user_status_url(user_status)
    end

    it 'returns user status with new setting added' do
      expect(update_user_status['settings'].to_h).to eq \
        'some_setting' => 'true',
        'new_setting' => 'false'
    end
  end
end
