# frozen_string_literal: true

class ThumbnailConsumer < Msgr::Consumer
  def fetch_thumbnails
    payload = @message.payload
    video_id = payload.fetch(:video_id)
    checksum = payload.fetch(:checksum)
    counter = payload.fetch(:counter, 0)
    url = payload.fetch(:thumbnail_fetch_url)

    digest = Digest::SHA256.hexdigest(video_id + Xikolo.base_url.host)
    return if checksum != digest

    video = Video.find_by(id: video_id)
    return unless video # Ignore videos that were deleted in the meantime

    # only the last triggered job will be processed
    return if video.thumbnail_job_counter > counter.to_i

    FetchThumbnailsWorker.perform_async(video_id, counter, url)
  end
end
