# frozen_string_literal: true

class DownloadsController < ApplicationController
  respond_to :json

  SUPPORTED_QUALITIES = %w[hd sd].freeze

  before_action :validate_quality
  before_action :check_availability

  rescue_from Vimeo::API::RequestTimeout, with: :vimeo_timeout_error

  def show
    render json: {
      link: downloads[params[:quality]],
    }
  end

  private

  def check_availability
    return if quality_available?

    error(:not_found, json: {error: 'quality_not_available'})
  end

  def quality_available?
    downloads[params[:quality]].present?
  end

  def validate_quality
    return if quality_supported?

    error(:unprocessable_entity, json: {error: 'quality_not_supported'})
  end

  def quality_supported?
    SUPPORTED_QUALITIES.include? params[:quality]
  end

  def downloads
    @downloads ||= begin
      stream = Stream.find params[:id]
      stream.current_downloads.stringify_keys
    end
  end

  def vimeo_timeout_error
    error(:gateway_timeout, json: {error: 'vimeo_api_did_not_respond'})
  end
end
