# frozen_string_literal: true

class LiveEventsController < ApplicationController
  responders Responders::DecorateResponder,
    Responders::HttpCacheResponder,
    Responders::PaginateResponder

  respond_to :json

  def index
    respond_with LiveEvent.not_deleted
  end

  def show
    respond_with LiveEvent.not_deleted.find params[:id]
  end

  def create
    live_event = LiveEvent.new live_event_params
    live_event.save
    respond_with live_event
  end

  def update
    live_event = LiveEvent.find(params[:id])
    live_event.update live_event_params
    respond_with live_event
  end

  def destroy
    live_event = LiveEvent.find(params[:id])
    live_event.soft_delete
    live_event.save
    respond_with live_event
  end

  private

  def live_event_params
    params.permit(
      :title,
      :description,
      :event_type,
      :speaker,
      :start_at,
      :further_info,
      :deleted,
      :live_video_id,
      :live_chat_id
    )
  end
end
