# frozen_string_literal: true

class ProvidersController < ApplicationController
  responders Responders::DecorateResponder,
    Responders::HttpCacheResponder,
    Responders::PaginateResponder

  respond_to :json

  def index
    providers = Provider.all
    providers.where! name: params[:name] if params[:name]
    providers.where! default: params[:default] if params[:default]
    respond_with providers
  end

  def show
    respond_with Provider.find params[:id]
  end

  def create
    respond_with Provider.create provider_params
  end

  def update
    provider = Provider.find params[:id]
    params.delete :token if params[:token].blank?
    respond_with provider.update provider_params
  end

  def destroy
    respond_with Provider.find(params[:id]).destroy
  end

  private

  def provider_params
    # Fill in provider type and credentials column
    # until support for multiple provider types is added
    # and therefore it is known which credentials are needed.
    #
    # TODO: update once provider types are implemented
    {
      provider_type: 'vimeo',
      credentials: {
        token: params[:token],
      },
    }.merge(params.permit(:name, :token, :default))
  end
end
