# frozen_string_literal: true

class StreamsController < ApplicationController
  responders Responders::DecorateResponder,
    Responders::HttpCacheResponder,
    Responders::PaginateResponder

  respond_to :json

  include HasProvider

  before_action :prevent_invalid_sort!, only: :index

  def index
    streams = Stream.includes(:provider).all
    streams.where! id: params[:id] if params[:id]
    streams.where! provider_video_id: params[:provider_video_id] if params[:provider_video_id]
    streams = filter_title(streams)

    if params[:prefix].present? || params[:sort] == 'title'
      streams.reorder!('title ASC')
    end

    respond_with streams
  end

  def show
    respond_with Stream.find params[:id]
  end

  def create
    respond_with Stream.create stream_params.merge!(provider:)
  end

  def update
    stream = Stream.find params[:id]
    stream.update stream_params
    respond_with stream
  end

  def destroy
    respond_with Stream.find(params[:id]).destroy
  end

  def per_page
    150
  end

  private

  # Filter either by full title or prefix
  def filter_title(streams)
    if params[:title]
      streams.where(title: params[:title])
    elsif params[:prefix].present?
      streams.by_prefix params[:prefix]
    else
      streams
    end
  end

  def prevent_invalid_sort!
    return if params[:sort].blank?
    return if params[:sort] == 'title'

    head :bad_request, content_type: 'text/plain'
  end

  def stream_params
    params.permit(
      :provider_video_id, :title, :height, :width, :hd_url, :sd_url, :hls_url,
      :hd_download_url, :sd_download_url, :poster, :duration
    )
  end
end
