# frozen_string_literal: true

class VideosController < ApplicationController
  responders Responders::DecorateResponder,
    Responders::HttpCacheResponder,
    Responders::PaginateResponder

  respond_to :json

  # GET /videos
  def index
    videos = Video.all
    videos.where! id: params[:id] if params[:id]
    videos.where! title: params[:title] if params[:title]
    videos.where! description: params[:description] if params[:description]
    videos.where! lecturer_stream_id: params[:lecturer_stream_id] if params[:lecturer_stream_id]
    videos.where! slides_stream_id: params[:slides_stream_id] if params[:slides_stream_id]
    videos.where! pip_stream_id: params[:pip_stream_id] if params[:pip_stream_id]
    respond_with videos
  end

  # GET /videos/1
  def show
    video = Video.find params[:id]
    response.link clone_video_url(video), rel: :clone
    respond_with video
  end

  # POST /videos
  def create
    video = Video::Update.call(Video.new, video_params)
    respond_with video
  end

  def clone
    video = Video::Clone.call Video.find params[:id]
    respond_with video
  end

  # PUT /videos/1
  def update
    video = Video.find params[:id]
    respond_with Video::Update.call(video, video_params)
  end

  # DELETE /videos/1
  def destroy
    video = Video.find params[:id]
    respond_with Video::Destroy.call(video)
  end

  def sync
    video = Video.find params[:id]
    video.sync
    head :created, content_type: 'text/plain'
  end

  def decoration_context
    case action_name
      when 'show'
        params.permit(:embed, :raw)
      else
        {}
    end
  end

  private

  def video_params
    params.permit(
      :title,
      :description,
      # stream references:
      :lecturer_stream_id,
      :slides_stream_id,
      :pip_stream_id,
      :subtitled_stream_id,
      # file uploads:
      :subtitles_upload_id,
      :slides_upload_id,
      :reading_material_upload_id,
      :transcript_upload_id,
      # remove attached files:
      :slides_url,
      :reading_material_url,
      :transcript_url
    )
  end
end
