# frozen_string_literal: true

class SubtitleCueDecorator < Draper::Decorator
  delegate_all

  def as_json(opts = {})
    {
      id:,
      subtitle_id:,
      identifier:,
      start:,
      end: stop,
      text:,
      settings:,
    }.as_json(opts)
  end

  def to_vtt
    "#{identifier}\n#{start} --> #{stop} #{settings}\n#{vtt_text}\n"
  end

  def settings
    object.style.map {|k, v| "#{k}:#{v}" }.join(' ')
  end

  def start
    WebVTT::Timestamp.new(object.start).to_s
  end

  def stop
    WebVTT::Timestamp.new(object.stop).to_s
  end

  def vtt_text
    text.gsub(
      /[&<>]/,
      '&' => '&amp;',
      '<' => '&lt;',
      '>' => '&gt;'
    )
  end
end
