# frozen_string_literal: true

class VideoDecorator < Draper::Decorator
  delegate_all

  decorates_association :subtitles

  def as_json(_opts = {})
    fields = {
      id:,
      title:,
      description:,
      lecturer_stream_id:,
      slides_stream_id:,
      pip_stream_id:,
      thumbnail:,
      duration:,
      subtitled_stream_id:,
      subtitles_url:,
      subtitles: subtitles.map(&:short),

      self_url:,
      slides_url:,
      audio_url:,
      transcript_url:,
      reading_material_url:,
      thumbnails_extraction_url: h.video_thumbnails_extraction_url(
        video_id: object.id
      ),
      sync_url: h.sync_single_video_url(id:),
    }

    if thumbnails_uri
      fields[:thumbnails_url] = h.video_thumbnails_url(video_id: object.id)
    end

    fields[:streams] = streams if embed? 'streams'

    fields.as_json
  end

  def description
    if context[:raw]
      Xikolo::S3.media_refs(object.description, public: true)
        .merge('markup' => object.description)
    else
      Xikolo::S3.externalize_file_refs(object.description, public: true)
    end
  end

  def self_url
    h.video_url to_param
  end

  def subtitles_url
    h.subtitles_url video_id: to_param
  end

  def embed?(key)
    context[:embed]&.include?(key)
  end

  def streams
    %i[
      lecturer_stream
      slides_stream
      pip_stream
      subtitled_stream
    ].each_with_object({}) do |name, hsh|
      stream = object.send(name)
      hsh[name] = stream.decorate if stream
    end
  end
end
