# frozen_string_literal: true

module FileReference
  extend ActiveSupport::Concern

  module ClassMethods
    @default_file_params = {}

    def file_reference(name, params = {})
      class_eval <<-RUBY_EVAL, __FILE__, __LINE__ + 1
        def #{name}_url                                              # def filename_url
          Xikolo::S3.object(#{name}_uri).public_url if #{name}_uri   #   Xikolo::S3.object(filename_uri).public_url if filename_uri
        end                                                          # end
      RUBY_EVAL

      # rubocop:disable Style/DocumentDynamicEvalDefinition
      class_eval <<-RUBY_EVAL, __FILE__, __LINE__ + 1
        def new_#{name}_file(params={})
          bucket = Xikolo::S3.bucket_for(:video)
          key_template = self.class.file_key_template(:#{name})
          key = key_template.call(self) + params[:key]
          params.reverse_merge! self.class.file_default_attributes(:#{name})
          object = bucket.object(key)
          uploaded = yield object, params
          self.#{name}_uri = object.storage_uri if uploaded
        end
      RUBY_EVAL
      # rubocop:enable all

      @file_default_attributes ||= {}
      @file_default_attributes[name] = params[:default_attributes]

      @file_key_templates ||= {}
      @file_key_templates[name] = params[:key_template]
    end

    def file_default_attributes(name)
      @file_default_attributes.fetch(name)
    end

    def file_key_template(name)
      @file_key_templates.fetch(name)
    end
  end
end
