# frozen_string_literal: true

class LiveEvent < ApplicationRecord
  validates :title, presence: true
  validates :description, presence: true
  validates :live_video_id, presence: true

  default_scope { order(start_at: :desc) }

  scope :not_deleted, -> { where(deleted: false) }

  after_create do
    Msgr.publish(decorate.as_event, to: 'xikolo.video.live_event.create')
  end
  after_update do
    Msgr.publish(decorate.as_event, to: 'xikolo.video.live_event.update')
  end
  after_destroy do
    Msgr.publish(decorate.as_event, to: 'xikolo.video.live_event.destroy')
  end

  def soft_delete
    self[:deleted] = true
  end
end
