# frozen_string_literal: true

require 'xikolo/s3'

class Video::Clone < ApplicationOperation
  def initialize(original_video)
    super()

    @original_video = original_video
  end

  def call
    Video.transaction do
      @video = Video.new(
        @original_video.attributes.except(
          'id', 'slides_uri', 'transcript_uri', 'reading_material_uri', 'thumbnails_uri'
        ).merge(id: SecureRandom.uuid)
      )

      # Clone file attachments
      @video.assign_attributes(
        slides_uri: copy_file(@original_video.slides_uri),
        transcript_uri: copy_file(@original_video.transcript_uri),
        reading_material_uri: copy_file(@original_video.reading_material_uri)
      )

      @video.save

      clone_subtitles!
    end

    @video
  end

  private

  def clone_subtitles!
    @original_video.subtitles.each do |subtitle|
      subtitle.clone video_id: @video.id
    end
  end

  def copy_file(uri)
    return unless uri

    original = Xikolo::S3.object(uri)
    # Replace video ID in key
    key = original.key.split('/').tap do |parts|
      parts[1] = UUID4(@video.id).to_s(format: :base62)
    end.join('/')

    Xikolo::S3.copy_to(original, target: key, bucket: :video, acl: 'public-read',
      content_disposition: original.content_disposition)
  end
end
