# frozen_string_literal: true

require 'streamio-ffmpeg'

class ExtractAudioWorker
  include Sidekiq::Job

  def perform(stream_id)
    stream = Stream.find stream_id
    old_object = stream.audio_uri if stream.audio_uri?

    # Download the file and extract its audio canal
    FFMPEG::Movie.new(stream.sd_url).transcode(
      mp3_file.path,
      audio_codec: 'libmp3lame',
      custom: %w[-qscale:a 6 -ac 1]
    )

    # store reference:
    object = upload_file(File.open(mp3_file), stream)

    stream.audio_uri = object.storage_uri
    stream.save!

    # remove old file:
    FileDeletionWorker.perform_in 1.hour, old_object if old_object
  end

  private

  def mp3_file
    @mp3_file ||= Tempfile.new %w[audio .mp3]
  end

  def upload_file(io, stream)
    sid = UUID4(stream.id).to_str(format: :base62)
    /.*_[rv](?<revision>[0-9]+)(?:\.[a-z]{2,4})?/ =~ stream.audio_uri
    revision ||= 0

    # upload audio:
    Xikolo::S3.bucket_for(:video).put_object(
      key: "streams/#{sid}/audio_v#{revision.to_i + 1}.mp3",
      body: io,
      acl: 'public-read',
      content_type: 'audio/mp3',
      cache_control: 'public, max-age=7776000',
      content_disposition: "attachment; filename=\"#{stream.title.underscore}_audio.mp3\""
    )
  end
end
