# frozen_string_literal: true

class SyncProviderWorker
  include Sidekiq::Job

  sidekiq_options queue: :provider_sync

  # Since this job is scheduled via cron anyway, we reduce the amount of retries:
  # 3 attempts, 10 minutes apart
  sidekiq_options retry: 3
  sidekiq_retry_in { 10.minutes.to_i }

  # rubocop:disable Style/OptionalBooleanParameter - keyword args not supported in Sidekiq
  def perform(provider = nil, full = false)
    return Provider.find(provider).sync(full:) if provider

    Provider.pluck(:id).each do |id|
      self.class.perform_async(id, full)
    end
  rescue ActiveRecord::RecordNotFound
    # noop
  end
  # rubocop:enable all
end
