# frozen_string_literal: true

module Vimeo
  class Download
    FIELDS = 'download'

    def initialize(downloads)
      @downloads = downloads
    end

    def to_hash
      return {} if @downloads.blank?

      {
        sd_url: links[:sd],
        hd_url: links[:hd],
        expires:,
      }
    end

    private

    def links
      # Often, two variants per quality are available. Select the best one by largest file size.
      @links ||= {
        sd: @downloads.select {|d| d['quality'] == 'sd' }.max_by {|d| d['size'] }&.fetch('link'),
        hd: @downloads.select {|d| d['quality'] == 'hd' }.max_by {|d| d['size'] }&.fetch('link'),
      }
    end

    def expires
      @expires ||= @downloads.first['expires']
    end
  end
end
