# frozen_string_literal: true

require 'spec_helper'

RSpec.describe ThumbnailsController, type: :controller do
  describe '#index' do
    subject(:list_thumbs) { -> { get :index, params: } }

    context 'without existing video' do
      let(:params) { {video_id: SecureRandom.uuid} }

      it 'returns an 404' do
        list_thumbs.call
        expect(response).to have_http_status :not_found
      end
    end

    context 'with video without thumbnails archive' do
      let(:params) { {video_id: video.id} }

      let(:video) { create(:video, thumbnails_uri: nil) }

      it 'returns an 404' do
        list_thumbs.call
        expect(response).to have_http_status :not_found
      end
    end

    context 'with video with thumbnails archive' do
      let(:params) { {video_id: video.id} }

      let(:video) { create(:video, thumbnails_uri: 's3://xikolo-video/videos/thumbnails.zip') }

      it 'returns an 200' do
        list_thumbs.call
        expect(response).to have_http_status :ok
      end
    end
  end

  describe '#extract' do
    subject(:extract_thumbs) { -> { post :extract, params: {video_id: video.id} } }

    let(:video) { create(:video) }

    it 'responds with 201 Created' do
      extract_thumbs.call
      expect(response).to have_http_status :created
    end

    it 'triggers the thumbnail extraction' do
      video
      expect { extract_thumbs.call }.to change(ThumbnailGenerationWorker.jobs, :size).by 1
    end
  end
end
