# frozen_string_literal: true

require 'spec_helper'

RSpec.describe VideoSyncsController, type: :controller do
  include_context 'default_provider'

  let(:json) { JSON.parse response.body }

  describe '#show' do
    subject(:show_sync) { get :show }

    it 'is successful' do
      show_sync
      expect(response).to have_http_status :ok
    end
  end

  describe '#create' do
    subject(:sync_videos) { post :create, params: }

    let(:provider) { create(:provider) }

    context 'when triggering a full sync' do
      let(:params) { {provider_id: provider.id, full: true} }

      it 'is successful' do
        sync_videos
        expect(response).to have_http_status :created
      end

      it 'schedules a sync job' do
        expect { sync_videos }.to change { SyncProviderWorker.jobs.size }.from(0).to(1)
        expect(SyncProviderWorker.jobs.first['args']).to eq [provider.id, true]
      end
    end

    context 'when triggering a partial sync' do
      let(:params) { {provider_id: provider.id, full: false} }

      it 'is successful' do
        sync_videos
        expect(response).to have_http_status :created
      end

      it 'schedules a sync job' do
        expect { sync_videos }.to change { SyncProviderWorker.jobs.size }.from(0).to(1)
        expect(SyncProviderWorker.jobs.first['args']).to eq [provider.id, false]
      end
    end
  end
end
