# frozen_string_literal: true

require 'spec_helper'

RSpec.describe SubtitleCueDecorator, type: :decorator do
  let(:cue) { described_class.new create(:subtitle_cue) }

  describe 'as_json' do
    subject { json }

    let(:json) { cue.as_json.stringify_keys }

    it { is_expected.to include('id') }
    it { is_expected.to include('subtitle_id') }
    it { is_expected.to include('identifier') }
    it { is_expected.to include('start') }
    it { is_expected.to include('end') }
    it { is_expected.to include('text') }
    it { is_expected.to include('settings') }
  end

  describe 'to_vtt' do
    subject { vtt }

    let(:vtt) { cue.to_vtt }

    it { is_expected.to eq "#{cue.identifier}\n#{cue.start} --> #{cue.stop} \nLorem ipsum dolor sit amet, consectetur adipiscing elit.\n" }

    context 'with style' do
      let(:cue) { described_class.new create(:subtitle_cue, :with_style) }

      it { is_expected.to eq "#{cue.identifier}\n#{cue.start} --> #{cue.stop} A:middle\nLorem ipsum dolor sit amet, consectetur adipiscing elit.\n" }
    end

    context 'with special characters' do
      let(:cue) { described_class.new create(:subtitle_cue, text: 'text with html & stuff <foo>') }

      it 'escapes those characters' do
        expect(vtt).to end_with("text with html &amp; stuff &lt;foo&gt;\n")
      end
    end
  end

  describe '#settings' do
    subject { cue.settings }

    let(:cue) { described_class.new create(:subtitle_cue, :with_style) }

    it { is_expected.to eq 'A:middle' }
  end
end
