# frozen_string_literal: true

FactoryBot.define do
  factory :video do
    id { SecureRandom.uuid }
    title             { 'Test Video' }
    description       { 'This video does not actually exist but is used for testing' }
    association :lecturer_stream, factory: :stream, strategy: :create
    association :slides_stream, factory: :stream, strategy: :create
    association :pip_stream, factory: :stream, strategy: :create
    association :subtitled_stream, factory: :stream, strategy: :create
    thumbnails_uri { "s3://xikolo-video/videos/#{id}/thumbnails.zip" }

    trait :without_streams do
      lecturer_stream { nil }
      slides_stream { nil }
      pip_stream { nil }
    end

    trait :with_slides do
      slides_uri { "s3://xikolo-video/videos/#{id}/encodedUUUID/slides.pdf" }
    end

    trait :with_transcript do
      transcript_uri { "s3://xikolo-video/videos/#{id}/encodedUUUID/transcript.pdf" }
    end

    trait :with_reading_material do
      reading_material_uri { "s3://xikolo-video/videos/#{id}/encodedUUUID/reading_material.pdf" }
    end
  end
end
