# frozen_string_literal: true

require 'spec_helper'

RSpec.describe LiveEvent, type: :model do
  context '(event publication)' do
    subject(:the_event) { build(:live_event) }

    it 'publishes an event for newly created live_event' do
      # Let the item factory also create the corresponding section and course
      the_event

      expect(Msgr).to receive(:publish).with(kind_of(Hash), hash_including(to: 'xikolo.video.live_event.create'))
      # During the first save we expect an event to be published
      the_event.save
    end

    it 'publishes an event for updated live_event' do
      the_event.save

      expect(Msgr).to receive(:publish) do |updated_live_event_as_hash, msgr_params|
        expect(updated_live_event_as_hash).to be_a(Hash)
        expect(updated_live_event_as_hash).to include('title' => 'New awesome openWHO live event')
        expect(msgr_params).to include(to: 'xikolo.video.live_event.update')
      end

      the_event.title = 'New awesome openWHO live event'
      the_event.save
    end

    it 'publishes an event for a destroyed live_event' do
      the_event.save

      expect(Msgr).to receive(:publish) do |destroyed_live_event_as_hash, msgr_params|
        expect(destroyed_live_event_as_hash).to be_a Hash
        expect(destroyed_live_event_as_hash).to include('title' => the_event.title)
        expect(msgr_params).to include(to: 'xikolo.video.live_event.destroy')
      end
      the_event.destroy
    end
  end
end
