# frozen_string_literal: true

require 'spec_helper'

RSpec.describe SubtitleCue, type: :model do
  let(:subtitle) { create(:subtitle) }
  let(:params)   { attributes_for(:subtitle_cue, subtitle:) }
  let(:cue)      { build(:subtitle_cue, params) }

  describe 'validations' do
    subject { cue }

    it { is_expected.not_to accept_values_for(:subtitle, nil) }
    it { is_expected.not_to accept_values_for(:identifier, '') }
    it { is_expected.not_to accept_values_for(:start, '') }
    it { is_expected.not_to accept_values_for(:stop, '') }

    describe '#start_before_stop' do
      context 'when start is earlier than stop' do
        before do
          cue.update(
            start: ActiveSupport::Duration.build(0),
            stop: ActiveSupport::Duration.build(10)
          )
        end

        it { expect(cue).to be_valid }
      end

      context 'when stop is later than start' do
        before do
          cue.update(
            start: ActiveSupport::Duration.build(10),
            stop: ActiveSupport::Duration.build(2)
          )
        end

        it 'raises an error' do
          expect(cue).not_to be_valid
          expect(cue.errors[:stop]).to match_array('invalid')
        end
      end
    end
  end

  context 'double identifier' do
    before { described_class.create params }

    describe 'creation fails' do
      subject { described_class.create params }

      it { is_expected.not_to be_valid }
    end
  end
end
