# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Live Events: Create', type: :request do
  subject(:create_event) { api.rel(:live_events).post(create_params).value! }

  let(:api) { Restify.new(:test).get.value }

  let(:create_params) { attributes_for(:live_event) }

  it { is_expected.to respond_with :created }

  it 'creates a new live_event' do
    expect { create_event }.to change(LiveEvent, :count).from(0).to(1)
  end

  context 'without description' do
    let(:create_params) { {title: 'title'} }

    it 'responds with 422 Unprocessable Entity' do
      expect { create_event }.to raise_error(Restify::ClientError) do |error|
        expect(error.status).to eq :unprocessable_entity
      end
    end
  end

  context 'without title' do
    let(:create_params) { {description: 'descriptive description'} }

    it 'responds with 422 Unprocessable Entity' do
      expect { create_event }.to raise_error(Restify::ClientError) do |error|
        expect(error.status).to eq :unprocessable_entity
      end
    end
  end
end
