# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Live Events: Show', type: :request do
  subject(:show_event) { api.rel(:live_event).get(params).value! }

  let(:api) { Restify.new(:test).get.value }
  let(:params) { {id: event.id} }
  let(:event) { create(:live_event) }

  before { event }

  it { is_expected.to respond_with :ok }

  it 'contains all attributes' do
    expect(show_event.keys).to match_array %w[id title description speaker start_at live_video_id live_chat_id further_info event_type]
  end

  context 'with a non-existent id' do
    let(:params) { {id: SecureRandom.uuid} }

    it 'responds with 404 Not Found' do
      expect { show_event }.to raise_error(Restify::ClientError) do |error|
        expect(error.status).to eq :not_found
      end
    end
  end

  context 'with deleted live event' do
    let(:event) { create(:live_event, deleted: true) }

    it 'responds with 404 Not Found' do
      expect { show_event }.to raise_error(Restify::ClientError) do |error|
        expect(error.status).to eq :not_found
      end
    end
  end
end
