# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Streams: List', type: :request do
  subject(:index) { api.rel(:streams).get(params).value! }

  let(:api) { Restify.new(:test).get.value }

  describe 'with sort' do
    before do
      create(:stream, title: 'C')
      create(:stream, title: 'A')
      create(:stream, title: 'B')
    end

    let(:params) { {sort: 'title'} }

    it 'returns streams ordered by title' do
      expect(index.pluck('title')).to eq %w[A B C]
    end

    context 'with invalid parameter value' do
      let(:params) { {sort: 'invalid'} }

      it { expect { index }.to raise_error Restify::BadRequest }
    end
  end

  describe 'escaping special characters' do
    before do
      create(:stream, title: 'A B C D')
      create(:stream, title: 'A B C %')
      create(:stream, title: 'B')
    end

    let(:params) { {prefix: 'A B C %'} }

    it 'returns only the escaped Stream' do
      expect(index.pluck('title')).to eq ['A B C %']
    end
  end
end
