# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Subtitles: Show', type: :request do
  let(:show_request) { get "/subtitles/#{subtitle.id}", headers: }

  let!(:subtitle) { create(:subtitle) }
  let(:default_params) { {} }
  let(:headers) { {} }

  describe '(response)' do
    subject(:subs) { show_request; response }

    it { is_expected.to have_http_status :ok }

    it 'responds with JSON content' do
      expect(subs['Content-Type']).to eq 'application/json; charset=utf-8'
    end

    it 'responds with a JSON serialization of the cues' do
      expect(JSON.parse(subs.body)).to include('cues')
    end

    context 'when requesting VTT representation' do
      let(:headers) { {'Accept' => 'text/vtt'} }

      it 'delivers plain WebVTT' do
        expect(subs.body).to eq "WEBVTT\n\n"
      end

      it 'responds with the correct MIME type' do
        expect(subs['Content-Type']).to eq 'text/vtt; charset=utf-8'
      end
    end
  end
end
