# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Thumbnails: Extract', type: :request do
  subject(:extract_thumbs) { video_api.rel(:thumbnails_extraction).post.value! }

  let(:video) { create(:video, thumbnails_uri: 's3://xikolo-video/videos/1/transcript_v1.zip') }
  let(:thumbnails) do
    create(:thumbnail)
    create(:thumbnail, video:)
    create(:thumbnail, video:)
  end

  let(:api) { Restify.new(:test).get.value! }
  let(:video_api) { api.rel(:video).get(id: video.id).value! }

  before { video; thumbnails }

  it 'responds with 201 Created' do
    expect(extract_thumbs).to respond_with :created
  end

  it 'accepts the request and schedule thumbnails regeneration' do
    expect { extract_thumbs }.to change { ThumbnailGenerationWorker.jobs.size }.by(1)
  end

  it 'deletes the existing thumbs' do
    expect { extract_thumbs }.to change { video.reload.thumbnails.count }.by(-2)
  end
end
