# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Thumbnails: Index', type: :request do
  subject(:get_thumbs) { video_api.rel(:thumbnails).get.value! }

  let(:video) { create(:video, thumbnails_uri: 's3://xikolo-video/videos/1/transcript.zip') }
  let(:thumbnails) do
    create(:thumbnail)
    create(:thumbnail, video:)
    create(:thumbnail, video:)
  end

  let(:api) { Restify.new(:test).get.value! }
  let(:video_api) { api.rel(:video).get(id: video.id).value! }

  before { video; thumbnails }

  describe '(response)' do
    it { is_expected.to respond_with :ok }

    context 'json content' do
      it 'returns two thumbnails' do
        expect(get_thumbs.count).to eq 2
      end

      it 'returns the two thumbnails order by start time' do
        expect(get_thumbs[0]['start_time']).to be < get_thumbs[1]['start_time']
      end

      it 'returns external storage URLs' do
        expect(get_thumbs[0]['file_url']).to start_with 'http://s3.xikolo.de/xikolo-video/'
        expect(get_thumbs[1]['file_url']).to start_with 'http://s3.xikolo.de/xikolo-video/'
        expect(get_thumbs[0]['file_url']).not_to eq get_thumbs[1]['file_url']
      end
    end
  end
end
