# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Video: Show', type: :request do
  subject(:show) { api.rel(:video).get(params).value! }

  let(:params) { {id: video.id} }
  let(:video) { create(:video) }
  let(:api) { Restify.new(:test).get.value }

  it { is_expected.to respond_with :ok }

  describe '#description' do
    let(:video) do
      create(:video,
        description: "test\ns3://xikolo-video/videos/3/rt/logo.jpg")
    end

    it 'returns text with public URLs' do
      expect(show['description']).to eq \
        "test\nhttp://s3.xikolo.de/xikolo-video/videos/3/rt/logo.jpg"
    end

    context 'in raw mode' do
      let(:params) { super().merge raw: true }

      it 'returns the text enhanced with url mappings and other files references' do
        expect(show['description']).to eq(
          'markup' =>
            "test\ns3://xikolo-video/videos/3/rt/logo.jpg",
          'url_mapping' => {
            's3://xikolo-video/videos/3/rt/logo.jpg' =>
               'http://s3.xikolo.de/xikolo-video/videos/3/rt/logo.jpg',
          },
          'other_files' => {
            's3://xikolo-video/videos/3/rt/logo.jpg' => 'logo.jpg',
          }
        )
      end
    end
  end
end
