# frozen_string_literal: true

require 'spec_helper'

RSpec.describe ExtractAudioWorker, type: :worker do
  describe '#perform' do
    let(:stream) do
      create(:stream,
        id: '72c75162-6aec-4a47-a74f-03a522290279',
        sd_url:,
        audio_uri:)
    end
    let(:sd_url) { 'spec/support/files/video-sd.mp4' }
    let(:audio_uri) { nil }
    let(:perform) do
      Sidekiq::Testing.inline! do
        described_class.perform_async(stream.id)
      end
    end

    it 'uploads a file to s3 and store its reference' do
      expect(stream.reload.audio_uri).to be_nil
      stub = stub_request(:put, 'http://s3.xikolo.de/xikolo-video/streams/3uAdfU6wveIxOGrQ7qa7mp/audio_v1.mp3')
      perform
      expect(stub).to have_been_requested
      expect(stream.reload.audio_uri).to eq 's3://xikolo-video/streams/3uAdfU6wveIxOGrQ7qa7mp/audio_v1.mp3'
    end

    context 'with previsously generated file' do
      let(:audio_uri) { 's3://xikolo-video/streams/3uAdfU6wveIxOGrQ7qa7mp/audio_v1.mp3' }

      it 'uploads a new file and delete the old one' do
        expect(stream.reload.audio_uri).not_to be_nil
        upload_stub = stub_request(:put, 'http://s3.xikolo.de/xikolo-video/streams/3uAdfU6wveIxOGrQ7qa7mp/audio_v2.mp3')
        delete_stub = stub_request(:delete, 'http://s3.xikolo.de/xikolo-video/streams/3uAdfU6wveIxOGrQ7qa7mp/audio_v1.mp3')
        perform
        expect(upload_stub).to have_been_requested
        expect(stream.reload.audio_uri).to eq 's3://xikolo-video/streams/3uAdfU6wveIxOGrQ7qa7mp/audio_v2.mp3'
        expect(delete_stub).to have_been_requested
      end
    end
  end
end
