# frozen_string_literal: true

require 'spec_helper'

RSpec.describe SyncProviderWorker, type: :worker do
  describe '#perform' do
    let(:providers) { create_list(:provider, 2) }
    let(:provider) { providers.first }

    before do
      Provider.delete_all
      allow(Provider).to receive(:find) do |id|
        providers.find {|p| p.id == id }
      end
    end

    it 'invokes sync an provider' do
      expect(provider).to receive(:sync)

      Sidekiq::Testing.inline! do
        described_class.perform_async(provider.id)
      end
    end

    context 'without arguments' do
      before { providers }

      it 'invokes sync on all providers' do
        expect(described_class).to receive(:perform_async)
          .exactly(3).times
          .and_call_original

        expect(providers[0]).to receive(:sync)
        expect(providers[1]).to receive(:sync)

        Sidekiq::Testing.inline! do
          described_class.perform_async
        end
      end
    end
  end
end
