# frozen_string_literal: true

require 'spec_helper'

describe 'Admin: Create Announcement', gen: 2, type: :feature do
  let(:user_id) { user['id'] }
  let(:user) { build(:'account:user') }

  before do
    stub_user id: user_id,
      permissions: %w[news.announcement.create],
      features: {'admin_announcements' => 'true'}
    Stub.service(:news, build(:'news:root'))

    Stub.request(:account, :get, "/users/#{user_id}")
      .to_return Stub.json(user)

    Stub.request(:news, :get, '/announcements')
      .and_return Stub.json([])
  end

  it 'announcement is created' do
    visit '/admin/announcements/new'

    within_fieldset('English') do
      fill_in 'Subject', with: 'This might interest you'
      fill_markdown_editor 'Content', with: 'Check it out!'
    end

    attributes = nil
    Stub.request(:news, :post, '/announcements').with do |request|
      attributes = JSON.parse request.body
      true
    end.to_return(status: 201)

    click_link_or_button 'Create announcement'

    expect(attributes).to include('author_id' => user_id)
    expect(attributes['translations']).to eq(
      'en' => {
        'subject' => 'This might interest you',
        'content' => 'Check it out!',
      }
    )
  end
end
