# frozen_string_literal: true

require 'spec_helper'

describe LearnerEvents::EnrollmentEvent do
  subject(:event) { described_class.new payload }

  let(:course) { create(:course, title: 'Great course', course_code: 'great-course') }
  let(:payload) do
    {
      id: 'a2f40994-d8c4-45dd-88a1-56e9e4dff3b1',
      user_id:,
      course_id: course.id,
      role: 'student',
    }
  end
  let(:user_id) { generate(:user_id) }

  before do
    Stub.request(
      :account, :get, "/users/#{user_id}"
    ).to_return Stub.json(build(:'account:user', id: user_id, name: 'John Doe'))
  end

  it 'serializes a hash of course attributes' do
    expect(event.for_json_activity_streams).to eq({
      'id' => 'a2f40994-d8c4-45dd-88a1-56e9e4dff3b1',
      'object' => {
        'id' => payload[:course_id],
        'objectType' => 'course',
        'displayName' => 'Great course',
        'url' => 'https://xikolo.de/courses/great-course',
      },
      'title' => 'User John Doe is enrolled in a course on Xikolo',
    })
  end
end
