# frozen_string_literal: true

require 'spec_helper'

describe PlatformLogin do
  # Ensure we always have a clean state for the login URL.
  around do |example|
    PlatformLogin.instance_variable_set :@login_url, nil
    example.run
  ensure
    PlatformLogin.instance_variable_set :@login_url, nil
  end

  describe '#external?' do
    it 'is internal' do
      expect(PlatformLogin).not_to be_external
    end
  end

  describe '#login_url' do
    it 'is the native login path' do
      expect(PlatformLogin.login_url).to eq 'https://xikolo.de/sessions/new'
    end
  end

  context 'with external login' do
    before do
      xi_config <<~YML
        portal_mode:
          external_login:
            enabled: true
            url: https://customer.example.com/login
      YML
    end

    describe '#external?' do
      it 'is external' do
        expect(PlatformLogin).to be_external
      end
    end

    describe '#login_url' do
      it 'is the native login path' do
        expect(PlatformLogin.login_url).to eq 'https://customer.example.com/login'
      end
    end

    context 'with missing url' do
      before do
        xi_config <<~YML
          portal_mode:
            external_login:
              enabled: true
        YML
      end

      describe '#login_url' do
        it 'raises Status::Redirect' do
          expect { PlatformLogin.login_url }.to raise_error(Status::Redirect, 'Redirect requested: Invalid external login URL')
        end
      end
    end

    context 'with invalid url' do
      before do
        xi_config <<~YML
          portal_mode:
            external_login:
              enabled: true
              url: 'http:'
        YML
      end

      describe '#login_url' do
        it 'raises Status::Redirect' do
          expect { PlatformLogin.login_url }.to raise_error(Status::Redirect, 'Redirect requested: Invalid external login URL')
        end
      end
    end
  end
end
