# frozen_string_literal: true

require 'spec_helper'

describe 'Admin: Videos: ThumbnailApiCallback', type: :request do
  let(:create_thumbnail) { post '/videos/thumbnail_api_callback', params:, headers: }
  let(:headers) { {} }
  let(:video_id) { '00000001-636e-4444-9999-000000000099' }
  let(:params) do
    {
      video_id:,
      checksum: 'some_checksum',
      Download_Link: 'some_link',
    }
  end
  let(:message) { params.merge(thumbnail_fetch_url: 'some_link').except(:Download_Link) }

  before { Stub.service(:video, build(:'video:root')) }

  context 'for logged-in users' do
    let(:headers) { {Authorization: "Xikolo-Session session_id=#{stub_session_id}"} }
    let(:permissions) { [] }

    before { stub_user_request permissions: }

    context 'with valid params' do
      it 'sends an AMQP message' do
        expect(Msgr).to receive(:publish) do |payload, opts|
          expect(payload).to include(message)
          expect(opts).to eq to: 'xikolo.video.thumbnail_fetch'
        end
        create_thumbnail
      end

      it 'responses with ok' do
        create_thumbnail
        expect(response.parsed_body['ok']).to be true
      end
    end

    context 'without valid params' do
      let(:params) { {} }

      it 'responses with a params error' do
        create_thumbnail
        expect(response.parsed_body['error']).to eq('params_missing')
      end
    end
  end

  context 'for anonymous users' do
    context 'with valid params' do
      it 'sends an AMQP message' do
        expect(Msgr).to receive(:publish) do |payload, opts|
          expect(payload).to include(message)
          expect(opts).to eq to: 'xikolo.video.thumbnail_fetch'
        end
        create_thumbnail
      end

      it 'responses with ok' do
        create_thumbnail
        expect(response.parsed_body['ok']).to be true
      end
    end

    context 'without valid params' do
      let(:params) { {} }

      it 'responses with a params error' do
        create_thumbnail
        expect(response.parsed_body['error']).to eq('params_missing')
      end
    end
  end
end
