# frozen_string_literal: true

require 'spec_helper'

describe 'Course: Admin: Open Badge Templates: Update', type: :request do
  subject(:update_template) do
    patch "/courses/#{course.course_code}/open_badge_templates/#{template.id}",
      params: {open_badge_template: params},
      headers:
  end

  let(:headers) { {'Authorization' => "Xikolo-Session session_id=#{stub_session_id}"} }
  let(:permissions) { %w[course.content.access certificate.template.manage] }
  let(:course) { create(:course) }
  let(:course_resource) { build(:'course:course', course_code: course.course_code) }
  let!(:template) do
    create(:open_badge_template,
      course:,
      name: 'Open Badge Template No. 1')
  end
  let(:params) { {name: 'Open Badge Template No. 99'} }

  before do
    stub_user_request(permissions:)

    Stub.service(:course, build(:'course:root'))
    Stub.request(:course, :get, "/courses/#{course.course_code}")
      .to_return Stub.json(course_resource)
  end

  it 'updates the Open Badge template' do
    expect { update_template }.to change { template.reload.name }
      .from('Open Badge Template No. 1')
      .to('Open Badge Template No. 99')
    expect(response).to redirect_to "/courses/#{course.course_code}/open_badge_templates"
  end

  context 'without permission to manage Open Badge templates' do
    let(:permissions) { %w[course.content.access] }

    it 'redirects the user' do
      update_template
      expect(response).to redirect_to '/'
    end
  end

  context 'without permission to access content' do
    let(:permissions) { %w[certificate.template.manage] }

    it 'redirects the user' do
      update_template
      expect(response).to redirect_to "/courses/#{course.course_code}"
    end
  end

  context 'for anonymous users' do
    let(:headers) { {} }

    it 'redirects the user' do
      update_template
      expect(response).to redirect_to "/courses/#{course.course_code}"
    end
  end
end
