# frozen_string_literal: true

require 'spec_helper'

describe 'Course: Sections: Index', type: :request do
  subject(:request) do
    get "/courses/#{course.course_code}/sections", headers:
  end

  let!(:group) { create(:group, course:) }
  let!(:stub_course) { build(:'course:course', course_code: 'course_1') }
  let!(:stub_section) { build(:'course:section', course_id: stub_course['id']) } # rubocop:disable RSpec/LetSetup
  let!(:course) { create(:course, id: stub_course['id'], course_code: 'course_1') }

  let(:content_test) { create(:content_test, course:, identifier: 'Gamification') }
  let!(:section) { create(:section, title: 'Week 1', course:) }
  let!(:fork) { create(:fork, section:, content_test:) }
  let(:branch) { create(:branch, group_id: group.id, fork:) }

  let(:page) { Capybara.fragment(response.body) }

  before do
    stub_user_request(id: user_id, permissions:)
    Stub.service(:course, build(:'course:root'))
    Stub.request(
      :course, :get, '/enrollments',
      query: {course_id: stub_course['id'], user_id:}
    ).to_return Stub.json([])
    Stub.request(
      :course, :get, '/next_dates',
      query: hash_including(course_id: stub_course['id'])
    ).to_return Stub.json([])
    Stub.request(
      :course, :get, '/courses/course_1'
    ).to_return Stub.json(stub_course)
  end

  context 'as logged in course admin' do
    let(:headers) { {Authorization: "Xikolo-Session session_id=#{stub_session_id}"} }
    let(:user_id) { generate(:user_id) }
    let(:permissions) { %w[course.content.access course.content.edit] }

    it 'displays the fork' do
      request
      expect(response).to be_successful
      expect(page).to have_content 'Week 1'
      expect(page).to have_content 'Fork'
      expect(page).to have_content 'Gamification'
    end
  end
end
