# frozen_string_literal: true

require 'spec_helper'

RSpec.describe 'Helpdesk: Create', type: :request do
  subject(:send_helpdesk) { post '/helpdesk', params: }

  let(:course) { build(:'course:course', id: generate(:course_id), title: 'First course') }
  let(:params) do
    {
      title: 'Test Ticket',
      mail: 'user@example.com',
      report: 'I have a problem',
      language: 'en',
      url: 'https://example.com/current/path',
    }
  end
  let(:page) { Capybara.fragment(response.body) }

  context 'anonymous user' do
    context 'technical question' do
      let(:params) { super().merge(category: 'technical') }

      it 'sets the params for the ticket correctly' do
        expect { send_helpdesk }.to change(Helpdesk::Ticket, :count).by(1)
        expect(Helpdesk::Ticket.first).to have_attributes(topic: 'technical', course_id: nil)
        expect(response).to have_http_status :ok
      end
    end

    context 'course-specific question' do
      let(:course_id) { generate(:course_id) }
      let(:params) { super().merge(category: course_id) }

      it 'sets the params for the ticket correctly' do
        expect { send_helpdesk }.to change(Helpdesk::Ticket, :count).by(1)
        expect(Helpdesk::Ticket.first).to have_attributes(topic: 'course', course_id:)
        expect(response).to have_http_status :ok
      end
    end

    context 'incorrect course ID parameter' do
      let(:params) { super().merge(category: '') }

      it 'assumes this is a technical question' do
        expect { send_helpdesk }.to change(Helpdesk::Ticket, :count).by(1)
        expect(Helpdesk::Ticket.first).to have_attributes(topic: 'technical', course_id: nil)
        expect(response).to have_http_status :ok
      end
    end
  end

  context 'with mail param missing' do
    let(:params) do
      {
        title: 'Test Ticket',
        report: 'I have a problem',
        language: 'en',
        url: 'https://example.com/current/path',
      }
    end

    it 'does not create a ticket and returns unprocessable_entity' do
      expect { send_helpdesk }.not_to change(Helpdesk::Ticket, :count)
      expect(response).not_to be_successful
      expect(response).to have_http_status :unprocessable_entity
      expect(page).to have_content 'Oops something went wrong.'
    end
  end
end
